@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.de", {
 		"Aktiviert die Inlay-Hinweise im Editor.",
 		"Steuert den Schriftgrad für Inlay-Hinweise im Editor. Wenn der Wert „0“ festgelegt wird, werden 90% von „#editor.fontSize#“ verwendet.",
 		"Steuert die Schriftfamilie für Inlay-Hinweise im Editor.",
-		"Steuert die Zeilenhöhe. Verwenden Sie 0, um die Zeilenhöhe aus der Schriftgröße zu berechnen.",
+		"Steuert die Zeilenhöhe. \r\n – Verwenden Sie 0, um die Zeilenhöhe automatisch anhand des Schriftgrads zu berechnen.\r\n – Werte zwischen 0 und 8 werden als Multiplikator mit dem Schriftgrad verwendet.\r\n – Werte größer oder gleich 8 werden als effektive Werte verwendet.",
 		"Steuert, ob die Minimap angezeigt wird.",
 		"Die Minimap hat die gleiche Größe wie der Editor-Inhalt (und kann scrollen).",
 		"Die Minimap wird bei Bedarf vergrößert oder verkleinert, um die Höhe des Editors zu füllen (kein Scrollen).",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.de", {
 		"Anzahl der Zeichen aus Festbreitenschriftarten, ab der dieses Editor-Lineal gerendert wird.",
 		"Farbe dieses Editor-Lineals.",
 		"Vertikale Linien nach einer bestimmten Anzahl von Monospacezeichen rendern. Verwenden Sie mehrere Werte für mehrere Linien. Wenn das Array leer ist, werden keine Linien gerendert.",
+		"Die vertikale Bildlaufleiste wird nur bei Bedarf angezeigt.",
+		"Die vertikale Bildlaufleiste ist immer sichtbar.",
+		"Die vertikale Bildlaufleiste wird immer ausgeblendet.",
+		"Steuert die Sichtbarkeit der vertikalen Bildlaufleiste.",
+		"Die horizontale Bildlaufleiste wird nur bei Bedarf angezeigt.",
+		"Die horizontale Bildlaufleiste ist immer sichtbar.",
+		"Die horizontale Bildlaufleiste wird immer ausgeblendet.",
+		"Steuert die Sichtbarkeit der horizontalen Bildlaufleiste.",
+		"Die Breite der vertikalen Bildlaufleiste.",
+		"Die Höhe der horizontalen Bildlaufleiste.",
+		"Steuert, ob Klicks nach Seite scrollen oder zur Klickposition springen.",
 		"Steuert, ob Inline-Vorschläge automatisch im Editor angezeigt werden.",
+		"Nur einen Inline-Vorschlag rendern, wenn der Ersatztext ein Präfix des Einfügetexts ist.",
+		"Nur einen Inline-Vorschlag rendern, wenn der Ersatztext ein Unterwort des Einfügetexts ist.",
+		"Steuert, welcher Modus zum Rendern der Inline-Vorschau verwendet werden soll.",
 		"Vorschlag einfügen, ohne den Text auf der rechten Seite des Cursors zu überschreiben",
 		"Vorschlag einfügen und Text auf der rechten Seite des Cursors überschreiben",
 		"Legt fest, ob Wörter beim Akzeptieren von Vervollständigungen überschrieben werden. Beachten Sie, dass dies von Erweiterungen abhängt, die für dieses Features aktiviert sind.",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.de", {
 		"Steuert, ob Symbole in Vorschlägen ein- oder ausgeblendet werden.",
 		"Steuert die Sichtbarkeit der Statusleiste unten im Vorschlagswidget.",
 		"Steuert, ob das Ergebnis des Vorschlags im Editor in der Vorschau angezeigt werden soll.",
+		"Rendern Sie einen Vorschlag nur, wenn der Ersatztext ein Präfix des Einfügetexts ist.",
+		"Rendern Sie einen Vorschlag nur, wenn der Ersatztext ein Unterwort des Einfügetexts ist.",
+		"Steuert, welcher Modus zum Rendern der Vorschlagsvorschau verwendet werden soll.",
 		"Steuert, ob Vorschlagsdetails inline mit der Bezeichnung oder nur im Detailwidget angezeigt werden.",
 		"Diese Einstellung ist veraltet. Die Größe des Vorschlagswidgets kann jetzt geändert werden.",
 		"Diese Einstellung ist veraltet. Verwenden Sie stattdessen separate Einstellungen wie \"editor.suggest.showKeywords\" oder \"editor.suggest.showSnippets\".",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.de", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"Wird geladen...",
+		"Die Tokenisierung wird bei langen Zeilen aus Leistungsgründen übersprungen. Dies kann über „editor.maxTokenizationLineLength“ konfiguriert werden.",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"Problem anzeigen",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.de", {
 		"Rahmenfarbe des Vorschlagswidgets.",
 		"Vordergrundfarbe des Vorschlagswidgets.",
 		"Die Vordergrundfarbe des ausgewählten Eintrags im Vorschlagswidget.",
+		"Die Vordergrundfarbe des Symbols des ausgewählten Eintrags im Vorschlagswidget.",
 		"Hintergrundfarbe des ausgewählten Eintrags im Vorschlagswidget.",
 		"Farbe der Trefferhervorhebung im Vorschlagswidget.",
 		"Die Farbe des Treffers wird im Vorschlagswidget hervorgehoben, wenn ein Element fokussiert wird.",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.de", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"Ungewöhnliche Zeilentrennzeichen",
 		"Ungewöhnliche Zeilentrennzeichen erkannt",
-		"Diese Datei enthält mindestens ein ungültiges Zeilenabschlusszeichen, z. B. Zeilentrennzeichen (LS) oder Absatztrennzeichen (PS).\r\n\r\nWir empfehlen, diese Zeichen über „editor.unusualLineTerminators“ aus der Datei zu entfernen.",
-		"Diese Datei korrigieren",
-		"Problem für diese Datei ignorieren",
+		"Die Datei \"{0}\" enthält mindestens ein ungewöhnliches Zeilenabschlusszeichen, z. B. Zeilentrennzeichen (LS) oder Absatztrennzeichen (PS).\r\n\r\nEs wird empfohlen, sie aus der Datei zu entfernen. Dies kann über \"editor.unusualLineTerminators\" konfiguriert werden.",
+		"Entfernen ungewöhnlicher Zeilenabschlusszeichen",
+		"Ignorieren",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"Hintergrundfarbe eines Symbols beim Lesezugriff, z.B. beim Lesen einer Variablen. Die Farbe darf nicht deckend sein, damit sie nicht die zugrunde liegenden Dekorationen verdeckt.",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.de", {
 		"zuletzt verwendet",
 		"andere Befehle",
 		"Der Befehl {0} hat einen Fehler ausgelöst ({1}).",
-		"OK",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"Globale Befehle",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.de", {
 		"Ein zusätzlicher Rahmen um Elemente, mit dem diese von anderen getrennt werden, um einen größeren Kontrast zu erreichen.",
 		"Ein zusätzlicher Rahmen um aktive Elemente, mit dem diese von anderen getrennt werden, um einen größeren Kontrast zu erreichen.",
 		"Vordergrundfarbe für Links im Text.",
+		"Vordergrundfarbe für angeklickte Links im Text und beim Zeigen darauf mit der Maus.",
 		"Hintergrundfarbe für Codeblöcke im Text.",
 		"Schattenfarbe von Widgets wie zum Beispiel Suchen/Ersetzen innerhalb des Editors.",
 		"Hintergrund für Eingabefeld.",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.de", {
 		"Konturfarbe der Liste/Struktur für das fokussierte Element, wenn die Liste/Struktur aktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Hintergrundfarbe der Liste/Struktur für das ausgewählte Element, wenn die Liste/Struktur aktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Vordergrundfarbe der Liste/Struktur für das ausgewählte Element, wenn die Liste/Struktur aktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
+		"Vordergrundfarbe des Symbols der Liste/Struktur für das ausgewählte Element, wenn die Liste/Struktur aktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Hintergrundfarbe der Liste/Struktur für das ausgewählte Element, wenn die Liste/Struktur inaktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Vordergrundfarbe der Liste/Struktur für das ausgewählte Element, wenn die Liste/Baumstruktur inaktiv ist. Eine aktive Liste/Baumstruktur hat Tastaturfokus, eine inaktive hingegen nicht.",
+		"Vordergrundfarbe des Symbols der Liste/Struktur für das ausgewählte Element, wenn die Liste/Struktur inaktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Hintergrundfarbe der Liste/Struktur für das fokussierte Element, wenn die Liste/Struktur inaktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Konturfarbe der Liste/Struktur für das fokussierte Element, wenn die Liste/Struktur inaktiv ist. Eine aktive Liste/Struktur hat Tastaturfokus, eine inaktive hingegen nicht.",
 		"Hintergrund der Liste/Struktur, wenn mit der Maus auf Elemente gezeigt wird.",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.de", {
 		"Strukturstrichfarbe für die Einzugsführungslinien.",
 		"Verwenden Sie stattdessen \"quickInputList.focusBackground\".",
 		"Die Hintergrundfarbe der Schnellauswahl für das fokussierte Element.",
+		"Die Vordergrundfarbe des Symbols der Schnellauswahl für das fokussierte Element.",
 		"Die Hintergrundfarbe der Schnellauswahl für das fokussierte Element.",
 		"Rahmenfarbe von Menüs.",
 		"Vordergrundfarbe von Menüelementen.",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.de", {
 		"Abbrechen",
 		"\"{0}\" konnte nicht rückgängig gemacht werden, weil bereits ein Vorgang zum Rückgängigmachen oder Wiederholen durchgeführt wird.",
 		"Möchten Sie \"{0}\" rückgängig machen?",
-		"Rückgängig machen",
+		"Ja",
 		"Abbrechen",
 		"\"{0}\" konnte nicht in allen Dateien wiederholt werden. {1}",
 		"\"{0}\" konnte nicht in allen Dateien wiederholt werden. {1}",
