@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.fr", {
 		"Active les indicateurs inlay dans l’éditeur.",
 		"Contrôle la taille de police des indicateurs inlay dans l’éditeur. Quand la valeur est définie sur `0`, 90 % de `#editor.fontSize#` est utilisé.",
 		"Contrôle la famille de polices des indicateurs inlay dans l’éditeur.",
-		"Contrôle la hauteur de ligne. Utilisez 0 pour calculer la hauteur de ligne de la taille de la police.",
+		"Contrôle la hauteur de ligne. \r\n - Utilisez 0 pour calculer automatiquement la hauteur de ligne à partir de la taille de police.\r\n : les valeurs comprises entre 0 et 8 sont utilisées comme multiplicateur avec la taille de police.\r\n : les valeurs supérieures ou égales à 8 seront utilisées comme valeurs effectives.",
 		"Contrôle si la minimap est affichée.",
 		"Le minimap a la même taille que le contenu de l\'éditeur (défilement possible).",
 		"Le minimap s\'agrandit ou se réduit selon les besoins pour remplir la hauteur de l\'éditeur (pas de défilement).",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.fr", {
 		"Nombre de caractères monospace auxquels cette règle d\'éditeur effectue le rendu.",
 		"Couleur de cette règle d\'éditeur.",
 		"Rendre les règles verticales après un certain nombre de caractères à espacement fixe. Utiliser plusieurs valeurs pour plusieurs règles. Aucune règle n\'est dessinée si le tableau est vide.",
+		"La barre de défilement verticale sera visible uniquement lorsque cela est nécessaire.",
+		"La barre de défilement verticale est toujours visible.",
+		"La barre de défilement verticale est toujours masquée.",
+		"Contrôle la visibilité de la barre de défilement verticale.",
+		"La barre de défilement horizontale sera visible uniquement lorsque cela est nécessaire.",
+		"La barre de défilement horizontale est toujours visible.",
+		"La barre de défilement horizontale est toujours masquée.",
+		"Contrôle la visibilité de la barre de défilement horizontale.",
+		"Largeur de la barre de défilement verticale.",
+		"Hauteur de la barre de défilement horizontale.",
+		"Contrôle si les clics permettent de faire défiler par page ou d’accéder à la position de clic.",
 		"Contrôle si les suggestions en ligne doivent être affichées automatiquement dans l’éditeur.",
+		"Affichez uniquement une suggestion inlined si le texte de remplacement est un préfixe du texte d’insertion.",
+		"Affichez uniquement une suggestion inlined si le texte de remplacement est un sous-mot du texte d’insertion.",
+		"Contrôle le mode à utiliser pour le rendu des suggestions incluses.",
 		"Insérez une suggestion sans remplacer le texte à droite du curseur.",
 		"Insérez une suggestion et remplacez le texte à droite du curseur.",
 		"Contrôle si les mots sont remplacés en cas d\'acceptation de la saisie semi-automatique. Notez que cela dépend des extensions adhérant à cette fonctionnalité.",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.fr", {
 		"Contrôle s\'il faut montrer ou masquer les icônes dans les suggestions.",
 		"Contrôle la visibilité de la barre d\'état en bas du widget de suggestion.",
 		"Contrôle si la sortie de la suggestion doit être affichée en aperçu dans l’éditeur.",
+		"Affichez un aperçu uniquement si le texte de remplacement est un préfixe du texte d’insertion.",
+		"Affichez un aperçu uniquement si le texte de remplacement est un sous-mot du texte d’insertion.",
+		"Contrôle le mode à utiliser pour le rendu de l’aperçu de suggestion.",
 		"Détermine si les détails du widget de suggestion sont inclus dans l\'étiquette ou uniquement dans le widget de détails",
 		"Ce paramètre est déprécié. Le widget de suggestion peut désormais être redimensionné.",
 		"Ce paramètre est déprécié, veuillez utiliser des paramètres distincts comme \'editor.suggest.showKeywords\' ou \'editor.suggest.showSnippets\' à la place.",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.fr", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"Chargement en cours...",
+		"La tokenisation des lignes longues est ignorée pour des raisons de performances. Cela peut être configurée via \'editor.maxTokenizationLineLength\'.",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"Voir le problème",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.fr", {
 		"Couleur de bordure du widget de suggestion.",
 		"Couleur de premier plan du widget de suggestion.",
 		"Couleur de premier plan de l’entrée sélectionnée dans le widget de suggestion.",
+		"Couleur de premier plan de l’icône de l’entrée sélectionnée dans le widget de suggestion.",
 		"Couleur d\'arrière-plan de l\'entrée sélectionnée dans le widget de suggestion.",
 		"Couleur de la surbrillance des correspondances dans le widget de suggestion.",
 		"Couleur des mises en surbrillance dans le widget de suggestion lorsqu’un élément a le focus.",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.fr", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"Marques de fin de ligne inhabituelles",
 		"Marques de fin de ligne inhabituelles détectées",
-		"Ce fichier contient un ou plusieurs caractères de fin de ligne inhabituels, par exemple le séparateur de ligne (LS) ou le séparateur de paragraphe (PS).\r\n\r\nIl est recommandé de les supprimer du fichier. Vous pouvez configurer ce comportement par le biais de `editor.unusualLineTerminators`.",
-		"Corriger ce fichier",
-		"Ignorer le problème pour ce fichier",
+		"Le fichier « {0} »contient un ou plusieurs caractères de fin de ligne inhabituels, par exemple le séparateur de ligne (LS) ou le séparateur de paragraphe (PS).\r\n\r\nIl est recommandé de les supprimer du fichier. Vous pouvez configurer ce comportement par le biais de `editor.unusualLineTerminators`.",
+		"Supprimer les marques de fin de ligne inhabituelles",
+		"Ignorer",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"Couleur d\'arrière-plan d\'un symbole pendant l\'accès en lecture, comme la lecture d\'une variable. La couleur ne doit pas être opaque pour ne pas masquer les ornements sous-jacents.",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.fr", {
 		"récemment utilisées",
 		"autres commandes",
 		"La commande \'{0}\' a entraîné une erreur ({1})",
-		"OK",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"commandes globales",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.fr", {
 		"Bordure supplémentaire autour des éléments pour les séparer des autres et obtenir un meilleur contraste.",
 		"Bordure supplémentaire autour des éléments actifs pour les séparer des autres et obtenir un meilleur contraste.",
 		"Couleur des liens dans le texte.",
+		"Couleur de premier plan pour les liens dans le texte lorsqu\'ils sont cliqués ou survolés.",
 		"Couleur d\'arrière-plan des blocs de code dans le texte.",
 		"Couleur de l\'ombre des widgets, comme rechercher/remplacer, au sein de l\'éditeur.",
 		"Arrière-plan de la zone d\'entrée.",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.fr", {
 		"Couleur de contour de la liste/l\'arborescence pour l\'élément ayant le focus quand la liste/l\'arborescence est active. Une liste/arborescence active a le focus clavier, contrairement à une liste/arborescence inactive.",
 		"Couleur d\'arrière-plan de la liste/l\'arborescence de l\'élément sélectionné quand la liste/l\'arborescence est active. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
 		"Couleur de premier plan de la liste/l\'arborescence pour l\'élément sélectionné quand la liste/l\'arborescence est active. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
+		"Couleur de premier plan de l’icône Liste/l\'arborescence pour l\'élément sélectionné quand la liste/l\'arborescence est active. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
 		"Couleur d\'arrière-plan de la liste/l\'arborescence pour l\'élément sélectionné quand la liste/l\'arborescence est inactive. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
 		"Couleur de premier plan de la liste/l\'arborescence pour l\'élément sélectionné quand la liste/l\'arborescence est inactive. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
+		"Couleur de premier plan de l’icône Liste/l\'arborescence pour l\'élément sélectionné quand la liste/l\'arborescence est inactive. Une liste/arborescence active peut être sélectionnée au clavier, elle ne l\'est pas quand elle est inactive.",
 		"Couleur d\'arrière-plan de la liste/l\'arborescence pour l\'élément ayant le focus quand la liste/l\'arborescence est active. Une liste/arborescence active peut être sélectionnée au clavier (elle ne l\'est pas quand elle est inactive).",
 		"Couleur de contour de la liste/l\'arborescence pour l\'élément ayant le focus quand la liste/l\'arborescence est inactive. Une liste/arborescence active a le focus clavier, contrairement à une liste/arborescence inactive.",
 		"Arrière-plan de la liste/l\'arborescence pendant le pointage sur des éléments avec la souris.",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.fr", {
 		"Couleur de trait de l\'arborescence pour les repères de mise en retrait.",
 		"Utilisez quickInputList.focusBackground à la place",
 		"Couleur de premier plan du sélecteur rapide pour l’élément ayant le focus.",
+		"Couleur de premier plan de l’icône du sélecteur rapide pour l’élément ayant le focus.",
 		"Couleur d\'arrière-plan du sélecteur rapide pour l\'élément ayant le focus.",
 		"Couleur de bordure des menus.",
 		"Couleur de premier plan des éléments de menu.",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.fr", {
 		"Annuler",
 		"Impossible d\'annuler \'{0}\', car une opération d\'annulation ou de rétablissement est déjà en cours d\'exécution.",
 		"Voulez-vous annuler \'{0}\' ?",
-		"Annuler",
+		"Oui",
 		"Annuler",
 		"Impossible de répéter \'{0}\' dans tous les fichiers. {1}",
 		"Impossible de répéter \'{0}\' dans tous les fichiers. {1}",
