@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"편집기에서 인레이 힌트를 사용하도록 설정합니다.",
 		"편집기에서 인레이 힌트의 글꼴 크기를 제어합니다. `0`으로 설정하면 `#editor.fontSize#`의 90%가 사용됩니다.",
 		"편집기에서 인레이 힌트의 글꼴 패밀리를 제어합니다.",
-		"줄 높이를 제어합니다. 글꼴 크기에서 줄 높이를 계산하려면 0을 사용합니다.",
+		"선 높이를 제어합니다. \r\n - 0을 사용하여 글꼴 크기에서 줄 높이를 자동으로 계산합니다.\r\n - 0에서 8 사이의 값은 글꼴 크기의 승수로 사용됩니다.\r\n - 8보다 크거나 같은 값이 유효 값으로 사용됩니다.",
 		"미니맵 표시 여부를 제어합니다.",
 		"미니맵의 크기는 편집기 내용과 동일하며 스크롤할 수 있습니다.",
 		"편집기의 높이를 맞추기 위해 필요에 따라 미니맵이 확장되거나 축소됩니다(스크롤 없음).",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.ko", {
 		"이 편집기 눈금자에서 렌더링할 고정 폭 문자 수입니다.",
 		"이 편집기 눈금자의 색입니다.",
 		"특정 수의 고정 폭 문자 뒤에 세로 눈금자를 렌더링합니다. 여러 눈금자의 경우 여러 값을 사용합니다. 배열이 비어 있는 경우 눈금자가 그려지지 않습니다.",
+		"세로 스크롤 막대는 필요한 경우에만 표시됩니다.",
+		"세로 스크롤 막대가 항상 표시됩니다.",
+		"세로 스크롤 막대를 항상 숨깁니다.",
+		"세로 스크롤 막대의 표시 유형을 제어합니다.",
+		"가로 스크롤 막대는 필요한 경우에만 표시됩니다.",
+		"가로 스크롤 막대가 항상 표시됩니다.",
+		"가로 스크롤 막대를 항상 숨깁니다.",
+		"가로 스크롤 막대의 표시 유형을 제어합니다.",
+		"세로 스크롤 막대의 너비입니다.",
+		"가로 스크롤 막대의 높이입니다.",
+		"클릭이 페이지별로 스크롤되는지 또는 클릭 위치로 이동할지 여부를 제어합니다.",
 		"편집기에서 인라인 제안을 자동으로 표시할지 여부를 제어합니다.",
+		"바꾸기 텍스트가 삽입 텍스트의 접두사인 경우에만 인라인 제안을 렌더링합니다.",
+		"바꾸기 텍스트가 삽입 텍스트의 하위 단어인 경우에만 인라인 제안을 렌더링합니다.",
+		"인라인 제안을 렌더링하는 데 사용할 모드를 제어합니다.",
 		"커서의 텍스트 오른쪽을 덮어 쓰지않고 제안을 삽입합니다.",
 		"제안을 삽입하고 커서의 오른쪽 텍스트를 덮어씁니다.",
 		"완료를 수락할 때 단어를 덮어쓸지 여부를 제어합니다. 이것은 이 기능을 선택하는 확장에 따라 다릅니다.",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"제안의 아이콘을 표시할지 여부를 제어합니다.",
 		"제안 위젯 하단의 상태 표시줄 가시성을 제어합니다.",
 		"편집기에서 제안 결과를 미리볼지 여부를 제어합니다.",
+		"바꾸기 텍스트가 삽입 텍스트의 접두사인 경우에만 미리 보기를 렌더링합니다.",
+		"바꾸기 텍스트가 삽입 텍스트의 하위 단어인 경우에만 미리 보기를 렌더링합니다.",
+		"제안 미리 보기를 렌더링하는 데 사용할 모드를 제어합니다.",
 		"제안 세부 정보가 레이블과 함께 인라인에 표시되는지 아니면 세부 정보 위젯에만 표시되는지를 제어합니다.",
 		"이 설정은 더 이상 사용되지 않습니다. 이제 제안 위젯의 크기를 조정할 수 있습니다.",
 		"이 설정은 더 이상 사용되지 않습니다. 대신 \'editor.suggest.showKeywords\'또는 \'editor.suggest.showSnippets\'와 같은 별도의 설정을 사용하세요.",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.ko", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"로드 중...",
+		"성능상의 이유로 긴 줄의 경우 토큰화를 건너뜁니다. 이 항목은 \'editor.maxTokenizationLineLength\'를 통해 구성할 수 있습니다.",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"문제 보기",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"제안 위젯의 테두리 색입니다.",
 		"제안 위젯의 전경색입니다.",
 		"제한 위젯에서 선택된 항목의 전경색입니다.",
+		"제한 위젯에서 선택된 항목의 아이콘 전경색입니다.",
 		"제한 위젯에서 선택된 항목의 배경색입니다.",
 		"제안 위젯의 일치 항목 강조 표시 색입니다.",
 		"항목에 포커스가 있을 때 추천 위젯에서 일치하는 항목의 색이 강조 표시됩니다.",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.ko", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"비정상적인 줄 종결자",
 		"비정상적인 줄 종결자가 검색됨",
-		"이 파일에 LS(줄 구분 기호) 또는 PS(단락 구분 기호) 같은 하나 이상의 비정상적인 줄 종결자 문자가 포함되어 있습니다.\r\n\r\n파일에서 제거하는 것이 좋습니다. `editor.unusualLineTerminators`를 통해 구성할 수 있습니다.",
-		"이 파일 수정",
-		"이 파일의 문제 무시",
+		"이 파일 ‘\r\n’에 LS(줄 구분 기호) 또는 PS(단락 구분 기호) 같은 하나 이상의 비정상적인 줄 종결자 문자가 포함되어 있습니다.{0}\r\n파일에서 제거하는 것이 좋습니다. `editor.unusualLineTerminators`를 통해 구성할 수 있습니다.",
+		"비정상적인 줄 종결자 제거",
+		"무시",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"변수 읽기와 같은 읽기 액세스 중 기호의 배경색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.ko", {
 		"최근에 사용한 항목",
 		"기타 명령",
 		"명령 \'{0}\'에서 오류({1})가 발생했습니다.",
-		"확인",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"전역 명령",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"더 뚜렷이 대비되도록 요소를 다른 요소와 구분하는 요소 주위의 추가 테두리입니다.",
 		"더 뚜렷이 대비되도록 요소를 다른 요소와 구분하는 활성 요소 주위의 추가 테두리입니다.",
 		"텍스트 내 링크의 전경색입니다.",
+		"클릭하고 마우스가 올라간 상태의 텍스트 내 링크의 전경색입니다.",
 		"텍스트 내 코드 블록의 전경색입니다.",
 		"편집기 내에서 찾기/바꾸기 같은 위젯의 그림자 색입니다.",
 		"입력 상자 배경입니다.",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.ko", {
 		"목록/트리가 활성 상태인 경우 포커스가 있는 항목의 목록/트리 윤곽선 색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 활성 상태인 경우 선택한 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 활성 상태인 경우 선택한 항목의 목록/트리 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
+		"목록/트리가 활성 상태인 경우 선택한 항목의 목록/트리 아이콘 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 선택한 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 선택한 항목의 목록/트리 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
+		"목록/트리가 비활성 상태인 경우 선택한 항목의 목록/트리 아이콘 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 포커스가 있는 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 포커스가 있는 항목의 목록/트리 윤곽선 색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"마우스로 항목을 가리킬 때 목록/트리 배경입니다.",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"들여쓰기 가이드의 트리 스트로크 색입니다.",
 		"대신 quickInputList.focusBackground를 사용하세요.",
 		"포커스가 있는 항목의 빠른 선택기 전경색입니다.",
+		"포커스가 있는 항목의 빠른 선택기 아이콘 전경색입니다.",
 		"포커스가 있는 항목의 빠른 선택기 배경색입니다.",
 		"메뉴 테두리 색입니다.",
 		"메뉴 항목 전경색입니다.",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"취소",
 		"실행 취소 또는 다시 실행 작업이 이미 실행 중이므로 \'{0}\'을(를) 실행 취소할 수 없습니다.",
 		"\'{0}\'을(를) 실행 취소하시겠습니까?",
-		"실행 취소",
+		"예",
 		"취소",
 		"모든 파일에서 \'{0}\'을(를) 다시 실행할 수 없습니다. {1}",
 		"모든 파일에서 \'{0}\'을(를) 다시 실행할 수 없습니다. {1}",
