@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"啟用編輯器中的內嵌提示。",
 		"控制編輯器中的內嵌提示字型大小。設定為 `0` 時，會使用 90% 的 `#editor.fontSize#`。",
 		"控制編輯器中的內嵌提示字型家族。",
-		"控制行高。使用 0 會從字型大小計算行高。",
+		"控制行高。\r\n - 使用 0 從字型大小自動計算行高。\r\n - 使用介於 0 和 8 之間的值作為字型大小的乘數。\r\n - 大於或等於 8 的值將用來作為有效值。",
 		"控制是否會顯示縮圖",
 		"縮圖大小與編輯器內容相同 (且可能會捲動)。",
 		"縮圖會視需要伸縮，以填滿該編輯器的高度 (無捲動)。",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"這個編輯器尺規會轉譯的等寬字元數。",
 		"此編輯器尺規的色彩。",
 		"在某個數目的等寬字元之後顯示垂直尺規。如有多個尺規，就會使用多個值。若陣列空白，就不會繪製任何尺規。",
+		"垂直捲軸只有在必要時才可見。",
+		"垂直捲軸永遠可見。",
+		"垂直捲軸永遠隱藏。",
+		"控制項垂直捲軸的可見度。",
+		"水平捲軸只有在必要時才可見。",
+		"水平捲軸永遠可見。",
+		"水平捲軸永遠隱藏。",
+		"控制項水平捲軸的可見度。",
+		"垂直捲軸的寬度。",
+		"水平捲軸的高度。",
+		"控制項按一下是否按頁面滾動或跳到按一下位置。",
 		"控制是否要在編輯器中自動顯示內嵌建議。",
+		"只有在取代文字是插入文字的前置詞時，才呈現內嵌建議。",
+		"只有在取代文字是插入文字的部分字組時，才呈現內嵌建議。",
+		"控制要用於呈現內嵌建議的模式。",
 		"插入建議而不覆寫游標旁的文字。",
 		"插入建議並覆寫游標旁的文字。",
 		"控制是否要在接受完成時覆寫字組。請注意，這取決於加入此功能的延伸模組。",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"控制要在建議中顯示或隱藏圖示。",
 		"控制建議小工具底下的狀態列可見度。",
 		"控制是否要在編輯器中預覽建議結果。",
+		"只有在取代文字是插入文字的前置詞時，才呈現預覽。",
+		"只有在取代文字是插入文字的部分字組時，才呈現預覽。",
+		"控制要用於呈現建議預覽的模式。",
 		"控制建議詳細資料是以內嵌於標籤的方式顯示，還是只在詳細資料小工具中顯示",
 		"此設定已淘汰。建議小工具現可調整大小。",
 		"此設定已淘汰，請改用 \'editor.suggest.showKeywords\' 或 \'editor.suggest.showSnippets\' 等單獨設定。",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"正在載入...",
+		"因效能的緣故，已跳過將長的行 Token 化。您可透過 `editor.maxTokenizationLineLength` 設定。",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"檢視問題",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"建議小工具的邊界色彩。",
 		"建議小工具的前景色彩。",
 		"建議小工具中所選項目的前景色彩。",
+		"建議小工具中所選項目的圖示前景色彩。",
 		"建議小工具中所選項目的背景色彩。",
 		"建議小工具中相符醒目提示的色彩。",
 		"當項目成為焦點時，相符項目的色彩在建議小工具中會醒目顯示。",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.zh-tw", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"異常的行結束字元",
 		"偵測到異常的行結束字元",
-		"此檔案包含一或多個異常的行結束字元，例如行分隔符號 (LS) 或段落分隔符號 (PS)。\r\n\r\n建議您將其從檔案中移除。這可以透過 `editor.unusualLineTerminators` 進行設定。",
-		"修正此檔案",
-		"忽略此檔案的問題",
+		"檔案 \'{0}\' 包含一或多個異常的行結束字元，例如行分隔符號 (LS) 或段落分隔符號 (PS)。\r\n\r\n建議您將其從檔案中移除。這可以透過 `editor.unusualLineTerminators` 進行設定。",
+		"移除異常的行結束字元",
+		"忽略",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"讀取權限期間 (如讀取變數) 符號的背景色彩。其不得為不透明色彩，以免隱藏底層裝飾。",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"最近使用的",
 		"其他命令",
 		"命令 \'{0}\' 造成錯誤 ({1})",
-		"確定",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"全域命令",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"項目周圍的額外框線，可將項目從其他項目中區隔出來以提高對比。",
 		"使用中項目周圍的額外邊界，可將項目從其他項目中區隔出來以提高對比。",
 		"內文連結的前景色彩",
+		"當滑鼠點擊或懸停時，文字中連結的前景色彩。",
 		"文字區塊的背景顏色。",
 		"小工具的陰影色彩，例如編輯器中的尋找/取代。",
 		"輸入方塊的背景。",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"當清單/樹狀目錄為使用中狀態時，焦點項目的清單/樹狀目錄外框色彩。使用中的清單/樹狀目錄有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
+		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀圖示前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為非使用中狀態時，所選項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為使用中狀態時，所選項目的清單/樹狀前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中則沒有。",
+		"當清單/樹狀為非使用中狀態時，所選項目的清單/樹狀圖示前景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀為非使用中狀態時，焦點項目的清單/樹狀背景色彩。使用中的清單/樹狀有鍵盤焦點，非使用中者則沒有。",
 		"當清單/樹狀目錄為非使用中狀態時，焦點項目的清單/樹狀目錄外框色彩。使用中的清單/樹狀目錄有鍵盤焦點，非使用中者則沒有。",
 		"使用滑鼠暫留在項目時的清單/樹狀背景。",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"縮排輔助線的樹狀筆觸色彩。",
 		"請改用 quickInputList.focusBackground",
 		"焦點項目的快速選擇器前景色彩。",
+		"焦點項目的快速選擇器圖示前景色彩。",
 		"焦點項目的快速選擇器背景色彩。",
 		"功能表的邊框色彩。",
 		"功能表項目的前景色彩。",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.zh-tw", {
 		"取消",
 		"因為已經有正在執行的復原或重做作業，所以無法復原 \'{0}\'。",
 		"要復原 \'{0}\' 嗎?",
-		"復原",
+		"是",
 		"取消",
 		"無法復原所有檔案的 \'{0}\'。{1}",
 		"無法復原所有檔案的 \'{0}\'。{1}",
