@@ -1,7 +1,3 @@
-/*---------------------------------------------------------------------------------------------
- *  Copyright (c) Microsoft Corporation. All rights reserved.
- *  Licensed under the MIT License. See License.txt in the project root for license information.
- *--------------------------------------------------------------------------------------------*/
 import { onUnexpectedError } from './errors.js';
 import { Disposable, combinedDisposable, DisposableStore } from './lifecycle.js';
 import { LinkedList } from './linkedList.js';
@@ -37,16 +33,14 @@ export var Event;
     }
     Event.once = once;
     /**
-     * Given an event and a `map` function, returns another event which maps each element
-     * through the mapping function.
+     * @deprecated DO NOT use, this leaks memory
      */
     function map(event, map) {
         return snapshot((listener, thisArgs = null, disposables) => event(i => listener.call(thisArgs, map(i)), null, disposables));
     }
     Event.map = map;
     /**
-     * Given an event and an `each` function, returns another identical event and calls
-     * the `each` function per each element.
+     * @deprecated DO NOT use, this leaks memory
      */
     function forEach(event, each) {
         return snapshot((listener, thisArgs = null, disposables) => event(i => { each(i); listener.call(thisArgs, i); }, null, disposables));
@@ -68,8 +62,7 @@ export var Event;
     }
     Event.any = any;
     /**
-     * Given an event and a `merge` function, returns another event which maps each element
-     * and the cumulative result through the `merge` function. Similar to `map`, but with memory.
+     * @deprecated DO NOT use, this leaks memory
      */
     function reduce(event, merge, initial) {
         let output = initial;
@@ -80,9 +73,7 @@ export var Event;
     }
     Event.reduce = reduce;
     /**
-     * Given a chain of event processing functions (filter, map, etc), each
-     * function will be invoked per event & per listener. Snapshotting an event
-     * chain allows each function to be invoked just once per event.
+     * @deprecated DO NOT use, this leaks memory
      */
     function snapshot(event) {
         let listener;
@@ -96,7 +87,9 @@ export var Event;
         });
         return emitter.event;
     }
-    Event.snapshot = snapshot;
+    /**
+     * @deprecated DO NOT use, this leaks memory
+     */
     function debounce(event, merge, delay = 100, leading = false, leakWarningThreshold) {
         let subscription;
         let output = undefined;
@@ -132,18 +125,7 @@ export var Event;
     }
     Event.debounce = debounce;
     /**
-     * Given an event, it returns another event which fires only once and as soon as
-     * the input event emits. The event data is the number of millis it took for the
-     * event to fire.
-     */
-    function stopwatch(event) {
-        const start = new Date().getTime();
-        return map(once(event), _ => new Date().getTime() - start);
-    }
-    Event.stopwatch = stopwatch;
-    /**
-     * Given an event, it returns another event which fires only when the event
-     * element changes.
+     * @deprecated DO NOT use, this leaks memory
      */
     function latch(event, equals = (a, b) => a === b) {
         let firstCall = true;
@@ -157,8 +139,7 @@ export var Event;
     }
     Event.latch = latch;
     /**
-     * Given an event, it returns another event which fires only when the event
-     * element changes.
+     * @deprecated DO NOT use, this leaks memory
      */
     function split(event, isT) {
         return [
@@ -168,26 +149,7 @@ export var Event;
     }
     Event.split = split;
     /**
-     * Buffers the provided event until a first listener comes
-     * along, at which point fire all the events at once and
-     * pipe the event from then on.
-     *
-     * ```typescript
-     * const emitter = new Emitter<number>();
-     * const event = emitter.event;
-     * const bufferedEvent = buffer(event);
-     *
-     * emitter.fire(1);
-     * emitter.fire(2);
-     * emitter.fire(3);
-     * // nothing...
-     *
-     * const listener = bufferedEvent(num => console.log(num));
-     * // 1, 2, 3
-     *
-     * emitter.fire(4);
-     * // 4
-     * ```
+     * @deprecated DO NOT use, this leaks memory
      */
     function buffer(event, nextTick = false, _buffer = []) {
         let buffer = _buffer.slice();
@@ -260,6 +222,9 @@ export var Event;
             return once(this.event)(listener, thisArgs, disposables);
         }
     }
+    /**
+     * @deprecated DO NOT use, this leaks memory
+     */
     function chain(event) {
         return new ChainableEvent(event);
     }
@@ -280,23 +245,6 @@ export var Event;
         return result.event;
     }
     Event.fromDOMEventEmitter = fromDOMEventEmitter;
-    function fromPromise(promise) {
-        const emitter = new Emitter();
-        let shouldEmit = false;
-        promise
-            .then(undefined, () => null)
-            .then(() => {
-            if (!shouldEmit) {
-                setTimeout(() => emitter.fire(undefined), 0);
-            }
-            else {
-                emitter.fire(undefined);
-            }
-        });
-        shouldEmit = true;
-        return emitter.event;
-    }
-    Event.fromPromise = fromPromise;
     function toPromise(event) {
         return new Promise(resolve => once(event)(resolve));
     }
@@ -541,6 +489,23 @@ export class PauseableEmitter extends Emitter {
         }
     }
 }
+export class DebounceEmitter extends PauseableEmitter {
+    constructor(options) {
+        var _a;
+        super(options);
+        this._delay = (_a = options.delay) !== null && _a !== void 0 ? _a : 100;
+    }
+    fire(event) {
+        if (!this._handle) {
+            this.pause();
+            this._handle = setTimeout(() => {
+                this._handle = undefined;
+                this.resume();
+            }, this._delay);
+        }
+        super.fire(event);
+    }
+}
 /**
  * The EventBufferer is useful in situations in which you want
  * to delay firing your events during some code.
