@@ -7,6 +7,7 @@ import { createStringBuilder } from '../../common/core/stringBuilder.js';
 import * as strings from '../../../base/common/strings.js';
 import { Configuration } from '../config/configuration.js';
 import { LineBreakData } from '../../common/viewModel/viewModel.js';
+import { LineInjectedText } from '../../common/model/textModelEvents.js';
 const ttPolicy = (_a = window.trustedTypes) === null || _a === void 0 ? void 0 : _a.createPolicy('domLineBreaksComputer', { createHTML: value => value });
 export class DOMLineBreaksComputerFactory {
     static create() {
@@ -18,22 +19,38 @@ export class DOMLineBreaksComputerFactory {
         tabSize = tabSize | 0; //@perf
         wrappingColumn = +wrappingColumn; //@perf
         let requests = [];
+        let injectedTexts = [];
         return {
-            addRequest: (lineText, previousLineBreakData) => {
+            addRequest: (lineText, injectedText, previousLineBreakData) => {
                 requests.push(lineText);
+                injectedTexts.push(injectedText);
             },
             finalize: () => {
-                return createLineBreaks(requests, fontInfo, tabSize, wrappingColumn, wrappingIndent);
+                return createLineBreaks(requests, fontInfo, tabSize, wrappingColumn, wrappingIndent, injectedTexts);
             }
         };
     }
 }
-function createLineBreaks(requests, fontInfo, tabSize, firstLineBreakColumn, wrappingIndent) {
+function createLineBreaks(requests, fontInfo, tabSize, firstLineBreakColumn, wrappingIndent, injectedTextsPerLine) {
     var _a;
+    function createEmptyLineBreakWithPossiblyInjectedText(requestIdx) {
+        const injectedTexts = injectedTextsPerLine[requestIdx];
+        if (injectedTexts) {
+            const lineText = LineInjectedText.applyInjectedText(requests[requestIdx], injectedTexts);
+            const injectionTexts = injectedTexts.map(t => t.text);
+            const injectionOffsets = injectedTexts.map(text => text.column - 1);
+            // creating a `LineBreakData` with an invalid `breakOffsetsVisibleColumn` is OK
+            // because `breakOffsetsVisibleColumn` will never be used because it contains injected text
+            return new LineBreakData([lineText.length], [], 0, injectionTexts, injectionOffsets);
+        }
+        else {
+            return null;
+        }
+    }
     if (firstLineBreakColumn === -1) {
         const result = [];
         for (let i = 0, len = requests.length; i < len; i++) {
-            result[i] = null;
+            result[i] = createEmptyLineBreakWithPossiblyInjectedText(i);
         }
         return result;
     }
@@ -52,7 +69,7 @@ function createLineBreaks(requests, fontInfo, tabSize, firstLineBreakColumn, wra
     const allCharOffsets = [];
     const allVisibleColumns = [];
     for (let i = 0; i < requests.length; i++) {
-        const lineContent = requests[i];
+        const lineContent = LineInjectedText.applyInjectedText(requests[i], injectedTextsPerLine[i]);
         let firstNonWhitespaceIndex = 0;
         let wrappedTextIndentLength = 0;
         let width = overallWidth;
@@ -103,7 +120,7 @@ function createLineBreaks(requests, fontInfo, tabSize, firstLineBreakColumn, wra
         const lineDomNode = lineDomNodes[i];
         const breakOffsets = readLineBreaks(range, lineDomNode, renderLineContents[i], allCharOffsets[i]);
         if (breakOffsets === null) {
-            result[i] = null;
+            result[i] = createEmptyLineBreakWithPossiblyInjectedText(i);
             continue;
         }
         const firstNonWhitespaceIndex = firstNonWhitespaceIndices[i];
@@ -119,7 +136,18 @@ function createLineBreaks(requests, fontInfo, tabSize, firstLineBreakColumn, wra
                 breakOffsets[j] += firstNonWhitespaceIndex;
             }
         }
-        result[i] = new LineBreakData(breakOffsets, breakOffsetsVisibleColumn, wrappedTextIndentLength);
+        let injectionTexts;
+        let injectionOffsets;
+        const curInjectedTexts = injectedTextsPerLine[i];
+        if (curInjectedTexts) {
+            injectionTexts = curInjectedTexts.map(t => t.text);
+            injectionOffsets = curInjectedTexts.map(text => text.column - 1);
+        }
+        else {
+            injectionTexts = null;
+            injectionOffsets = null;
+        }
+        result[i] = new LineBreakData(breakOffsets, breakOffsetsVisibleColumn, wrappedTextIndentLength, injectionTexts, injectionOffsets);
     }
     document.body.removeChild(containerDomNode);
     return result;
