@@ -105,6 +105,11 @@ export class EditorScrollbar extends ViewPart {
             const fastScrollSensitivity = options.get(32 /* fastScrollSensitivity */);
             const scrollPredominantAxis = options.get(93 /* scrollPredominantAxis */);
             const newOpts = {
+                vertical: scrollbar.vertical,
+                horizontal: scrollbar.horizontal,
+                verticalScrollbarSize: scrollbar.verticalScrollbarSize,
+                horizontalScrollbarSize: scrollbar.horizontalScrollbarSize,
+                scrollByPage: scrollbar.scrollByPage,
                 handleMouseWheel: scrollbar.handleMouseWheel,
                 mouseWheelScrollSensitivity: mouseWheelScrollSensitivity,
                 fastScrollSensitivity: fastScrollSensitivity,
