@@ -5,6 +5,7 @@
 import * as strings from '../../../base/common/strings.js';
 export class Viewport {
     constructor(top, left, width, height) {
+        this._viewportBrand = undefined;
         this.top = top | 0;
         this.left = left | 0;
         this.width = width | 0;
@@ -18,28 +19,58 @@ export class OutputPosition {
     }
 }
 export class LineBreakData {
-    constructor(breakOffsets, breakOffsetsVisibleColumn, wrappedTextIndentLength) {
+    constructor(breakOffsets, breakOffsetsVisibleColumn, wrappedTextIndentLength, injectionTexts, injectionOffsets) {
         this.breakOffsets = breakOffsets;
         this.breakOffsetsVisibleColumn = breakOffsetsVisibleColumn;
         this.wrappedTextIndentLength = wrappedTextIndentLength;
+        this.injectionTexts = injectionTexts;
+        this.injectionOffsets = injectionOffsets;
     }
-    static getInputOffsetOfOutputPosition(breakOffsets, outputLineIndex, outputOffset) {
+    getInputOffsetOfOutputPosition(outputLineIndex, outputOffset) {
+        let inputOffset = 0;
         if (outputLineIndex === 0) {
-            return outputOffset;
+            inputOffset = outputOffset;
         }
         else {
-            return breakOffsets[outputLineIndex - 1] + outputOffset;
+            inputOffset = this.breakOffsets[outputLineIndex - 1] + outputOffset;
         }
+        if (this.injectionOffsets !== null) {
+            for (let i = 0; i < this.injectionOffsets.length; i++) {
+                if (inputOffset > this.injectionOffsets[i]) {
+                    if (inputOffset < this.injectionOffsets[i] + this.injectionTexts[i].length) {
+                        // `inputOffset` is within injected text
+                        inputOffset = this.injectionOffsets[i];
+                    }
+                    else {
+                        inputOffset -= this.injectionTexts[i].length;
+                    }
+                }
+                else {
+                    break;
+                }
+            }
+        }
+        return inputOffset;
     }
-    static getOutputPositionOfInputOffset(breakOffsets, inputOffset) {
+    getOutputPositionOfInputOffset(inputOffset) {
+        let delta = 0;
+        if (this.injectionOffsets !== null) {
+            for (let i = 0; i < this.injectionOffsets.length; i++) {
+                if (inputOffset < this.injectionOffsets[i]) {
+                    break;
+                }
+                delta += this.injectionTexts[i].length;
+            }
+        }
+        inputOffset += delta;
         let low = 0;
-        let high = breakOffsets.length - 1;
+        let high = this.breakOffsets.length - 1;
         let mid = 0;
         let midStart = 0;
         while (low <= high) {
             mid = low + ((high - low) / 2) | 0;
-            const midStop = breakOffsets[mid];
-            midStart = mid > 0 ? breakOffsets[mid - 1] : 0;
+            const midStop = this.breakOffsets[mid];
+            midStart = mid > 0 ? this.breakOffsets[mid - 1] : 0;
             if (inputOffset < midStart) {
                 high = mid - 1;
             }
@@ -61,6 +92,7 @@ export class MinimapLinesRenderingData {
 }
 export class ViewLineData {
     constructor(content, continuesWithWrappedLine, minColumn, maxColumn, startVisibleColumn, tokens) {
+        this._viewLineDataBrand = undefined;
         this.content = content;
         this.continuesWithWrappedLine = continuesWithWrappedLine;
         this.minColumn = minColumn;
@@ -104,6 +136,7 @@ export class InlineDecoration {
 }
 export class ViewModelDecoration {
     constructor(range, options) {
+        this._viewModelDecorationBrand = undefined;
         this.range = range;
         this.options = options;
     }
