@@ -90,6 +90,10 @@ export function getRealAndSyntheticDocumentFormattersOrdered(model) {
     return result;
 }
 export class FormattingConflicts {
+    static setFormatterSelector(selector) {
+        const remove = FormattingConflicts._selectors.unshift(selector);
+        return { dispose: remove };
+    }
     static select(formatter, document, mode) {
         return __awaiter(this, void 0, void 0, function* () {
             if (formatter.length === 0) {
@@ -99,7 +103,7 @@ export class FormattingConflicts {
             if (selector) {
                 return yield selector(formatter, document, mode);
             }
-            return formatter[0];
+            return undefined;
         });
     }
 }
@@ -140,21 +144,70 @@ export function formatDocumentRangesWithProvider(accessor, provider, editorOrMod
                 len = ranges.push(range);
             }
         }
-        const allEdits = [];
-        for (let range of ranges) {
-            try {
-                const rawEdits = yield provider.provideDocumentRangeFormattingEdits(model, range, model.getFormattingOptions(), cts.token);
-                const minEdits = yield workerService.computeMoreMinimalEdits(model.uri, rawEdits);
-                if (minEdits) {
-                    allEdits.push(...minEdits);
+        const computeEdits = (range) => __awaiter(this, void 0, void 0, function* () {
+            return (yield provider.provideDocumentRangeFormattingEdits(model, range, model.getFormattingOptions(), cts.token)) || [];
+        });
+        const hasIntersectingEdit = (a, b) => {
+            if (!a.length || !b.length) {
+                return false;
+            }
+            // quick exit if the list of ranges are completely unrelated [O(n)]
+            const mergedA = a.reduce((acc, val) => { return Range.plusRange(acc, val.range); }, a[0].range);
+            if (!b.some(x => { return Range.intersectRanges(mergedA, x.range); })) {
+                return false;
+            }
+            // fallback to a complete check [O(n^2)]
+            for (let edit of a) {
+                for (let otherEdit of b) {
+                    if (Range.intersectRanges(edit.range, otherEdit.range)) {
+                        return true;
+                    }
                 }
+            }
+            return false;
+        };
+        const allEdits = [];
+        const rawEditsList = [];
+        try {
+            for (let range of ranges) {
                 if (cts.token.isCancellationRequested) {
                     return true;
                 }
+                rawEditsList.push(yield computeEdits(range));
             }
-            finally {
-                cts.dispose();
+            for (let i = 0; i < ranges.length; ++i) {
+                for (let j = i + 1; j < ranges.length; ++j) {
+                    if (cts.token.isCancellationRequested) {
+                        return true;
+                    }
+                    if (hasIntersectingEdit(rawEditsList[i], rawEditsList[j])) {
+                        // Merge ranges i and j into a single range, recompute the associated edits
+                        const mergedRange = Range.plusRange(ranges[i], ranges[j]);
+                        const edits = yield computeEdits(mergedRange);
+                        ranges.splice(j, 1);
+                        ranges.splice(i, 1);
+                        ranges.push(mergedRange);
+                        rawEditsList.splice(j, 1);
+                        rawEditsList.splice(i, 1);
+                        rawEditsList.push(edits);
+                        // Restart scanning
+                        i = 0;
+                        j = 0;
+                    }
+                }
             }
+            for (let rawEdits of rawEditsList) {
+                if (cts.token.isCancellationRequested) {
+                    return true;
+                }
+                const minimalEdits = yield workerService.computeMoreMinimalEdits(model.uri, rawEdits);
+                if (minimalEdits) {
+                    allEdits.push(...minimalEdits);
+                }
+            }
+        }
+        finally {
+            cts.dispose();
         }
         if (allEdits.length === 0) {
             return false;
