@@ -2,6 +2,15 @@
  *  Copyright (c) Microsoft Corporation. All rights reserved.
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
+var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
+    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
+    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
+    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
+    return c > 3 && r && Object.defineProperty(target, key, r), r;
+};
+var __param = (this && this.__param) || function (paramIndex, decorator) {
+    return function (target, key) { decorator(target, key, paramIndex); }
+};
 var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
     function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
     return new (P || (P = Promise))(function (resolve, reject) {
@@ -19,12 +28,14 @@ import { Disposable, toDisposable } from '../../../base/common/lifecycle.js';
 import * as strings from '../../../base/common/strings.js';
 import { Range } from '../../common/core/range.js';
 import { InlineCompletionsProviderRegistry, InlineCompletionTriggerKind } from '../../common/modes.js';
-import { BaseGhostTextWidgetModel } from './ghostTextWidget.js';
 import { EditOperation } from '../../common/core/editOperation.js';
+import { ICommandService } from '../../../platform/commands/common/commands.js';
 import { MutableDisposable } from './utils.js';
 import { RedoCommand, UndoCommand } from '../../browser/editorExtensions.js';
 import { CoreEditingCommands } from '../../browser/controller/coreCommands.js';
-export class InlineCompletionsModel extends Disposable {
+import { stringDiff } from '../../../base/common/diff/diff.js';
+import { GhostText, BaseGhostTextWidgetModel } from './ghostText.js';
+let InlineCompletionsModel = class InlineCompletionsModel extends Disposable {
     constructor(editor, commandService) {
         super();
         this.editor = editor;
@@ -96,9 +107,9 @@ export class InlineCompletionsModel extends Disposable {
         if (this.session && this.session.isValid) {
             return;
         }
-        this.startSession();
+        this.trigger();
     }
-    startSession() {
+    trigger() {
         if (this.completionSession.value) {
             return;
         }
@@ -124,8 +135,19 @@ export class InlineCompletionsModel extends Disposable {
         var _a;
         (_a = this.session) === null || _a === void 0 ? void 0 : _a.showPreviousInlineCompletion();
     }
-}
-class InlineCompletionsSession extends BaseGhostTextWidgetModel {
+    hasMultipleInlineCompletions() {
+        var _a;
+        return __awaiter(this, void 0, void 0, function* () {
+            const result = yield ((_a = this.session) === null || _a === void 0 ? void 0 : _a.hasMultipleInlineCompletions());
+            return result !== undefined ? result : false;
+        });
+    }
+};
+InlineCompletionsModel = __decorate([
+    __param(1, ICommandService)
+], InlineCompletionsModel);
+export { InlineCompletionsModel };
+export class InlineCompletionsSession extends BaseGhostTextWidgetModel {
     constructor(editor, triggerPosition, shouldUpdate, commandService) {
         super(editor);
         this.triggerPosition = triggerPosition;
@@ -150,6 +172,11 @@ class InlineCompletionsSession extends BaseGhostTextWidgetModel {
                 }
             }
         }));
+        this._register(this.editor.onDidChangeCursorPosition((e) => {
+            if (this.cache.value) {
+                this.onDidChangeEmitter.fire();
+            }
+        }));
         this._register(this.editor.onDidChangeModelContent((e) => {
             if (this.cache.value) {
                 let hasChanged = false;
@@ -170,6 +197,9 @@ class InlineCompletionsSession extends BaseGhostTextWidgetModel {
             }
             this.scheduleAutomaticUpdate();
         }));
+        this._register(InlineCompletionsProviderRegistry.onDidChange(() => {
+            this.updateSoon.schedule();
+        }));
         this.scheduleAutomaticUpdate();
     }
     fixAndGetIndexOfCurrentSelection() {
@@ -242,10 +272,18 @@ class InlineCompletionsSession extends BaseGhostTextWidgetModel {
             }
         });
     }
+    hasMultipleInlineCompletions() {
+        var _a;
+        return __awaiter(this, void 0, void 0, function* () {
+            yield this.ensureUpdateWithExplicitContext();
+            return (((_a = this.cache.value) === null || _a === void 0 ? void 0 : _a.completions.length) || 0) > 1;
+        });
+    }
     //#endregion
     get ghostText() {
         const currentCompletion = this.currentCompletion;
-        return currentCompletion ? inlineCompletionToGhostText(currentCompletion, this.editor.getModel()) : undefined;
+        const mode = this.editor.getOptions().get(52 /* inlineSuggest */).mode;
+        return currentCompletion ? inlineCompletionToGhostText(currentCompletion, this.editor.getModel(), mode, this.editor.getSelection().getEndPosition()) : undefined;
     }
     get currentCompletion() {
         const completion = this.currentCachedCompletion;
@@ -303,6 +341,11 @@ class InlineCompletionsSession extends BaseGhostTextWidgetModel {
         this._register(disposable);
     }
     commitCurrentCompletion() {
+        if (!this.ghostText) {
+            // No ghost text was shown for this completion.
+            // Thus, we don't want to commit anything.
+            return;
+        }
         const completion = this.currentCompletion;
         if (completion) {
             this.commit(completion);
@@ -390,46 +433,59 @@ class CachedInlineCompletion {
         this.synchronizedRange = inlineCompletion.range;
     }
 }
-function leftTrim(str) {
-    return str.replace(/^\s+/, '');
-}
-export function inlineCompletionToGhostText(inlineCompletion, textModel) {
+export function inlineCompletionToGhostText(inlineCompletion, textModel, mode, cursorPosition) {
+    if (inlineCompletion.range.startLineNumber !== inlineCompletion.range.endLineNumber) {
+        // Only single line replacements are supported.
+        return undefined;
+    }
     // This is a single line string
     const valueToBeReplaced = textModel.getValueInRange(inlineCompletion.range);
-    let remainingInsertText;
-    // Consider these cases
-    // valueToBeReplaced -> inlineCompletion.text
-    // "\t\tfoo" -> "\t\tfoobar" (+"bar")
-    // "\t" -> "\t\tfoobar" (+"\tfoobar")
-    // "\t\tfoo" -> "\t\t\tfoobar" (+"\t", +"bar")
-    // "\t\tfoo" -> "\tfoobar" (-"\t", +"\bar")
-    const firstNonWsCol = textModel.getLineFirstNonWhitespaceColumn(inlineCompletion.range.startLineNumber);
-    if (inlineCompletion.text.startsWith(valueToBeReplaced)) {
-        remainingInsertText = inlineCompletion.text.substr(valueToBeReplaced.length);
-    }
-    else if (firstNonWsCol === 0 || inlineCompletion.range.startColumn < firstNonWsCol) {
-        // Only allow ignoring leading whitespace in indentation.
-        // This prevents flickering when the user types whitespace that extends an empty range.
-        const valueToBeReplacedTrimmed = leftTrim(valueToBeReplaced);
-        const insertTextTrimmed = leftTrim(inlineCompletion.text);
-        if (!insertTextTrimmed.startsWith(valueToBeReplacedTrimmed)) {
+    const changes = cachingDiff(valueToBeReplaced, inlineCompletion.text);
+    const lineNumber = inlineCompletion.range.startLineNumber;
+    const parts = new Array();
+    if (mode === 'prefix') {
+        const filteredChanges = changes.filter(c => c.originalLength === 0);
+        if (filteredChanges.length > 1 || filteredChanges.length === 1 && filteredChanges[0].originalStart !== valueToBeReplaced.length) {
+            // Prefixes only have a single change.
             return undefined;
         }
-        remainingInsertText = insertTextTrimmed.substr(valueToBeReplacedTrimmed.length);
+    }
+    for (const c of changes) {
+        const insertColumn = inlineCompletion.range.startColumn + c.originalStart + c.originalLength;
+        if (cursorPosition && cursorPosition.lineNumber === inlineCompletion.range.startLineNumber && insertColumn < cursorPosition.column) {
+            // No ghost text before cursor
+            return undefined;
+        }
+        if (c.originalLength > 0) {
+            const originalText = valueToBeReplaced.substr(c.originalStart, c.originalLength);
+            const firstNonWsCol = textModel.getLineFirstNonWhitespaceColumn(lineNumber);
+            if (!(/^(\t| )*$/.test(originalText) && (firstNonWsCol === 0 || insertColumn <= firstNonWsCol))) {
+                return undefined;
+            }
+        }
+        if (c.modifiedLength === 0) {
+            continue;
+        }
+        const text = inlineCompletion.text.substr(c.modifiedStart, c.modifiedLength);
+        const lines = strings.splitLines(text);
+        parts.push({ column: insertColumn, lines });
+    }
+    return new GhostText(lineNumber, parts, 0);
+}
+let lastRequest = undefined;
+function cachingDiff(originalValue, newValue) {
+    if ((lastRequest === null || lastRequest === void 0 ? void 0 : lastRequest.originalValue) === originalValue && (lastRequest === null || lastRequest === void 0 ? void 0 : lastRequest.newValue) === newValue) {
+        return lastRequest === null || lastRequest === void 0 ? void 0 : lastRequest.changes;
     }
     else {
-        return undefined;
+        const changes = stringDiff(originalValue, newValue, false);
+        lastRequest = {
+            originalValue,
+            newValue,
+            changes
+        };
+        return changes;
     }
-    const position = inlineCompletion.range.getEndPosition();
-    const lines = strings.splitLines(remainingInsertText);
-    if (lines.length > 1 && textModel.getLineMaxColumn(position.lineNumber) !== position.column) {
-        // Such ghost text is not supported.
-        return undefined;
-    }
-    return {
-        lines,
-        position
-    };
 }
 function getDefaultRange(position, model) {
     const word = model.getWordAtPosition(position);
