@@ -60,23 +60,23 @@ let LinkedEditingContribution = class LinkedEditingContribution extends Disposab
         this._currentRequest = null;
         this._currentRequestPosition = null;
         this._currentRequestModelVersion = null;
-        this._register(this._editor.onDidChangeModel(() => this.reinitialize()));
+        this._register(this._editor.onDidChangeModel(() => this.reinitialize(true)));
         this._register(this._editor.onDidChangeConfiguration(e => {
             if (e.hasChanged(59 /* linkedEditing */) || e.hasChanged(79 /* renameOnType */)) {
-                this.reinitialize();
+                this.reinitialize(false);
             }
         }));
-        this._register(LinkedEditingRangeProviderRegistry.onDidChange(() => this.reinitialize()));
-        this._register(this._editor.onDidChangeModelLanguage(() => this.reinitialize()));
-        this.reinitialize();
+        this._register(LinkedEditingRangeProviderRegistry.onDidChange(() => this.reinitialize(false)));
+        this._register(this._editor.onDidChangeModelLanguage(() => this.reinitialize(true)));
+        this.reinitialize(true);
     }
     static get(editor) {
         return editor.getContribution(LinkedEditingContribution.ID);
     }
-    reinitialize() {
+    reinitialize(forceRefresh) {
         const model = this._editor.getModel();
         const isEnabled = model !== null && (this._editor.getOption(59 /* linkedEditing */) || this._editor.getOption(79 /* renameOnType */)) && LinkedEditingRangeProviderRegistry.has(model);
-        if (isEnabled === this._enabled) {
+        if (isEnabled === this._enabled && !forceRefresh) {
             return;
         }
         this._enabled = isEnabled;
