@@ -796,6 +796,7 @@ module.exports = {
 	"11.4.10": "87.0.4280.141",
 	"11.4.11": "87.0.4280.141",
 	"11.4.12": "87.0.4280.141",
+	"11.5.0": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -863,6 +864,10 @@ module.exports = {
 	"12.0.15": "89.0.4389.128",
 	"12.0.16": "89.0.4389.128",
 	"12.0.17": "89.0.4389.128",
+	"12.0.18": "89.0.4389.128",
+	"12.1.0": "89.0.4389.128",
+	"12.1.1": "89.0.4389.128",
+	"12.1.2": "89.0.4389.128",
 	"13.0.0-beta.2": "90.0.4402.0",
 	"13.0.0-beta.3": "90.0.4402.0",
 	"13.0.0-beta.4": "90.0.4415.0",
@@ -952,6 +957,9 @@ module.exports = {
 	"13.2.0": "91.0.4472.164",
 	"13.2.1": "91.0.4472.164",
 	"13.2.2": "91.0.4472.164",
+	"13.2.3": "91.0.4472.164",
+	"13.3.0": "91.0.4472.164",
+	"13.4.0": "91.0.4472.164",
 	"14.0.0-beta.1": "92.0.4511.0",
 	"14.0.0-beta.2": "92.0.4511.0",
 	"14.0.0-beta.3": "92.0.4511.0",
@@ -974,6 +982,8 @@ module.exports = {
 	"14.0.0-beta.21": "93.0.4577.15",
 	"14.0.0-beta.22": "93.0.4577.25",
 	"14.0.0-beta.23": "93.0.4577.25",
+	"14.0.0-beta.24": "93.0.4577.51",
+	"14.0.0-beta.25": "93.0.4577.51",
 	"14.0.0-nightly.20210304": "90.0.4402.0",
 	"14.0.0-nightly.20210305": "90.0.4415.0",
 	"14.0.0-nightly.20210308": "90.0.4415.0",
@@ -1016,6 +1026,8 @@ module.exports = {
 	"14.0.0-nightly.20210520": "92.0.4511.0",
 	"14.0.0-nightly.20210523": "92.0.4511.0",
 	"14.0.0-nightly.20210524": "92.0.4511.0",
+	"14.0.0": "93.0.4577.58",
+	"14.0.1": "93.0.4577.63",
 	"15.0.0-alpha.1": "93.0.4566.0",
 	"15.0.0-alpha.2": "93.0.4566.0",
 	"15.0.0-alpha.3": "94.0.4584.0",
@@ -1025,6 +1037,14 @@ module.exports = {
 	"15.0.0-alpha.7": "94.0.4590.2",
 	"15.0.0-alpha.8": "94.0.4590.2",
 	"15.0.0-alpha.9": "94.0.4590.2",
+	"15.0.0-alpha.10": "94.0.4606.12",
+	"15.0.0-beta.1": "94.0.4606.20",
+	"15.0.0-beta.2": "94.0.4606.20",
+	"15.0.0-beta.3": "94.0.4606.31",
+	"15.0.0-beta.4": "94.0.4606.31",
+	"15.0.0-beta.5": "94.0.4606.31",
+	"15.0.0-beta.6": "94.0.4606.31",
+	"15.0.0-beta.7": "94.0.4606.31",
 	"15.0.0-nightly.20210527": "92.0.4511.0",
 	"15.0.0-nightly.20210528": "92.0.4511.0",
 	"15.0.0-nightly.20210531": "92.0.4511.0",
@@ -1064,6 +1084,7 @@ module.exports = {
 	"15.0.0-nightly.20210719": "93.0.4566.0",
 	"15.0.0-nightly.20210720": "93.0.4566.0",
 	"15.0.0-nightly.20210721": "93.0.4566.0",
+	"15.0.0": "94.0.4606.51",
 	"16.0.0-nightly.20210722": "93.0.4566.0",
 	"16.0.0-nightly.20210723": "93.0.4566.0",
 	"16.0.0-nightly.20210726": "93.0.4566.0",
@@ -1086,5 +1107,26 @@ module.exports = {
 	"16.0.0-nightly.20210818": "94.0.4590.2",
 	"16.0.0-nightly.20210819": "94.0.4590.2",
 	"16.0.0-nightly.20210820": "94.0.4590.2",
-	"16.0.0-nightly.20210823": "94.0.4590.2"
+	"16.0.0-nightly.20210823": "94.0.4590.2",
+	"16.0.0-nightly.20210824": "95.0.4612.5",
+	"16.0.0-nightly.20210825": "95.0.4612.5",
+	"16.0.0-nightly.20210826": "95.0.4612.5",
+	"16.0.0-nightly.20210827": "95.0.4612.5",
+	"16.0.0-nightly.20210830": "95.0.4612.5",
+	"16.0.0-nightly.20210831": "95.0.4612.5",
+	"16.0.0-nightly.20210901": "95.0.4612.5",
+	"16.0.0-nightly.20210902": "95.0.4629.0",
+	"16.0.0-nightly.20210903": "95.0.4629.0",
+	"16.0.0-nightly.20210906": "95.0.4629.0",
+	"16.0.0-nightly.20210907": "95.0.4629.0",
+	"16.0.0-nightly.20210908": "95.0.4629.0",
+	"16.0.0-nightly.20210909": "95.0.4629.0",
+	"16.0.0-nightly.20210910": "95.0.4629.0",
+	"16.0.0-nightly.20210913": "95.0.4629.0",
+	"16.0.0-nightly.20210914": "95.0.4629.0",
+	"16.0.0-nightly.20210915": "95.0.4629.0",
+	"16.0.0-nightly.20210916": "95.0.4629.0",
+	"16.0.0-nightly.20210917": "95.0.4629.0",
+	"16.0.0-nightly.20210920": "95.0.4629.0",
+	"16.0.0-nightly.20210921": "95.0.4629.0"
 };
\ No newline at end of file
