@@ -67,9 +67,7 @@ ContentTypeParser.prototype.add = function (contentType, opts, parserFn) {
     this.customParsers[''] = parser
   } else {
     if (contentTypeIsString) {
-      if (contentType !== 'application/json' && contentType !== 'text/plain') {
-        this.parserList.unshift(contentType)
-      }
+      this.parserList.unshift(contentType)
     } else {
       this.parserRegExpList.unshift(contentType)
     }
@@ -83,10 +81,10 @@ ContentTypeParser.prototype.hasParser = function (contentType) {
 
 ContentTypeParser.prototype.existingParser = function (contentType) {
   if (contentType === 'application/json') {
-    return this.customParsers['application/json'].fn !== this[kDefaultJsonParse]
+    return this.customParsers['application/json'] && this.customParsers['application/json'].fn !== this[kDefaultJsonParse]
   }
   if (contentType === 'text/plain') {
-    return this.customParsers['text/plain'].fn !== defaultPlainTextParser
+    return this.customParsers['text/plain'] && this.customParsers['text/plain'].fn !== defaultPlainTextParser
   }
 
   return contentType in this.customParsers
@@ -116,6 +114,27 @@ ContentTypeParser.prototype.getParser = function (contentType) {
   return this.customParsers['']
 }
 
+ContentTypeParser.prototype.removeAll = function () {
+  this.customParsers = {}
+  this.parserRegExpList = []
+  this.parserList = []
+  this.cache = lru(100)
+}
+
+ContentTypeParser.prototype.remove = function (contentType) {
+  if (!(typeof contentType === 'string' || contentType instanceof RegExp)) throw new FST_ERR_CTP_INVALID_TYPE()
+
+  delete this.customParsers[contentType]
+
+  const parsers = typeof contentType === 'string' ? this.parserList : this.parserRegExpList
+
+  const idx = parsers.findIndex(ct => ct.toString() === contentType.toString())
+
+  if (idx > -1) {
+    parsers.splice(idx, 1)
+  }
+}
+
 ContentTypeParser.prototype.run = function (contentType, handler, request, reply) {
   const parser = this.cache.get(contentType) || this.getParser(contentType)
 
@@ -297,11 +316,35 @@ function hasContentTypeParser (contentType) {
   return this[kContentTypeParser].hasParser(contentType)
 }
 
+function removeContentTypeParser (contentType) {
+  if (this[kState].started) {
+    throw new Error('Cannot call "removeContentTypeParser" when fastify instance is already started!')
+  }
+
+  if (Array.isArray(contentType)) {
+    for (const type of contentType) {
+      this[kContentTypeParser].remove(type)
+    }
+  } else {
+    this[kContentTypeParser].remove(contentType)
+  }
+}
+
+function removeAllContentTypeParsers () {
+  if (this[kState].started) {
+    throw new Error('Cannot call "removeAllContentTypeParsers" when fastify instance is already started!')
+  }
+
+  this[kContentTypeParser].removeAll()
+}
+
 module.exports = ContentTypeParser
 module.exports.helpers = {
   buildContentTypeParser,
   addContentTypeParser,
-  hasContentTypeParser
+  hasContentTypeParser,
+  removeContentTypeParser,
+  removeAllContentTypeParsers
 }
 module.exports.defaultParsers = {
   getDefaultJsonParser,
