@@ -4,8 +4,8 @@ module.exports = {
   kResuming: Symbol('resuming'),
   kQueue: Symbol('queue'),
   kConnect: Symbol('connect'),
-  kIdleTimeout: Symbol('idle timeout'),
-  kIdleTimeoutValue: Symbol('idle timeout value'),
+  kConnecting: Symbol('connecting'),
+  kHeadersList: Symbol('headers list'),
   kKeepAliveDefaultTimeout: Symbol('default keep alive timeout'),
   kKeepAliveMaxTimeout: Symbol('max keep alive timeout'),
   kKeepAliveTimeoutThreshold: Symbol('keep alive timeout threshold'),
@@ -13,9 +13,16 @@ module.exports = {
   kKeepAlive: Symbol('keep alive'),
   kHeadersTimeout: Symbol('headers timeout'),
   kBodyTimeout: Symbol('body timeout'),
-  kTLSServerName: Symbol('server name'),
+  kServerName: Symbol('server name'),
   kHost: Symbol('host'),
-  kTLSOpts: Symbol('TLS Options'),
+  kNoRef: Symbol('no ref'),
+  kBodyUsed: Symbol('used'),
+  kRunning: Symbol('running'),
+  kBlocking: Symbol('blocking'),
+  kPending: Symbol('pending'),
+  kSize: Symbol('size'),
+  kBusy: Symbol('busy'),
+  kConnected: Symbol('connected'),
   kClosed: Symbol('closed'),
   kNeedDrain: Symbol('need drain'),
   kReset: Symbol('reset'),
@@ -24,14 +31,14 @@ module.exports = {
   kRunningIdx: Symbol('running index'),
   kPendingIdx: Symbol('pending index'),
   kError: Symbol('error'),
+  kClients: Symbol('clients'),
   kClient: Symbol('client'),
   kParser: Symbol('parser'),
   kOnDestroyed: Symbol('destroy callbacks'),
   kPipelining: Symbol('pipelinig'),
-  kSocketPath: Symbol('socket path'),
   kSocket: Symbol('socket'),
-  kTLSSession: Symbol('tls session cache'),
   kHostHeader: Symbol('host header'),
-  kAgentOpts: Symbol('agent opts'),
-  kAgentCache: Symbol('agent cache')
+  kConnector: Symbol('connector'),
+  kStrictContentLength: Symbol('strict content length'),
+  kMaxRedirections: Symbol('maxRedirections')
 }
