@@ -22,13 +22,7 @@ function decorate (instance, name, fn, dependencies) {
     throw new FST_ERR_DEC_ALREADY_PRESENT(name)
   }
 
-  if (dependencies) {
-    if (!Array.isArray(dependencies)) {
-      throw new FST_ERR_DEC_DEPENDENCY_INVALID_TYPE(name)
-    }
-
-    checkDependencies(instance, dependencies)
-  }
+  checkDependencies(instance, name, dependencies)
 
   if (fn && (typeof fn.getter === 'function' || typeof fn.setter === 'function')) {
     Object.defineProperty(instance, name, {
@@ -40,6 +34,26 @@ function decorate (instance, name, fn, dependencies) {
   }
 }
 
+function decorateConstructor (konstructor, name, fn, dependencies) {
+  const instance = konstructor.prototype
+  if (instance.hasOwnProperty(name) || konstructor.props.includes(name)) {
+    throw new FST_ERR_DEC_ALREADY_PRESENT(name)
+  }
+
+  checkDependencies(instance, name, dependencies)
+
+  if (fn && (typeof fn.getter === 'function' || typeof fn.setter === 'function')) {
+    Object.defineProperty(instance, name, {
+      get: fn.getter,
+      set: fn.setter
+    })
+  } else if (fn !== undefined && fn !== null) {
+    instance[name] = fn
+  } else {
+    konstructor.props.push(name)
+  }
+}
+
 function checkReferenceType (name, fn) {
   if (typeof fn === 'object' && fn && !(typeof fn.getter === 'function' || typeof fn.setter === 'function')) {
     warning.emit('FSTDEP006', name)
@@ -61,14 +75,24 @@ function checkExistence (instance, name) {
 }
 
 function checkRequestExistence (name) {
+  if (name && this[kRequest].props.includes(name)) return true
   return checkExistence(this[kRequest].prototype, name)
 }
 
 function checkReplyExistence (name) {
+  if (name && this[kReply].props.includes(name)) return true
   return checkExistence(this[kReply].prototype, name)
 }
 
-function checkDependencies (instance, deps) {
+function checkDependencies (instance, name, deps) {
+  if (deps === undefined || deps === null) {
+    return
+  }
+
+  if (!Array.isArray(deps)) {
+    throw new FST_ERR_DEC_DEPENDENCY_INVALID_TYPE(name)
+  }
+
   // eslint-disable-next-line no-var
   for (var i = 0; i !== deps.length; ++i) {
     if (!checkExistence(instance, deps[i])) {
@@ -80,14 +104,14 @@ function checkDependencies (instance, deps) {
 function decorateReply (name, fn, dependencies) {
   assertNotStarted(this, name)
   checkReferenceType(name, fn)
-  decorate(this[kReply].prototype, name, fn, dependencies)
+  decorateConstructor(this[kReply], name, fn, dependencies)
   return this
 }
 
 function decorateRequest (name, fn, dependencies) {
   assertNotStarted(this, name)
   checkReferenceType(name, fn)
-  decorate(this[kRequest].prototype, name, fn, dependencies)
+  decorateConstructor(this[kRequest], name, fn, dependencies)
   return this
 }
 
