@@ -1,7 +1,7 @@
 'use strict'
 
-const EventEmitter = require('events')
-const Client = require('./core/client')
+const Dispatcher = require('./dispatcher')
+const Client = require('./client')
 const {
   ClientClosedError,
   InvalidArgumentError,
@@ -9,6 +9,9 @@ const {
 } = require('./core/errors')
 const FixedQueue = require('./node/fixed-queue')
 const util = require('./core/util')
+const { kSize, kRunning, kUrl, kPending, kBusy } = require('./core/symbols')
+const assert = require('assert')
+const buildConnector = require('./core/connect')
 
 const kClients = Symbol('clients')
 const kNeedDrain = Symbol('needDrain')
@@ -17,51 +20,88 @@ const kDestroyed = Symbol('destroyed')
 const kClosedPromise = Symbol('closed promise')
 const kClosedResolve = Symbol('closed resolve')
 const kOptions = Symbol('options')
-const kUrl = Symbol('url')
 const kOnDrain = Symbol('onDrain')
 const kOnConnect = Symbol('onConnect')
 const kOnDisconnect = Symbol('onDisconnect')
-const kPending = Symbol('pending')
-const kConnected = Symbol('connected')
+const kOnConnectionError = Symbol('onConnectionError')
 const kConnections = Symbol('connections')
+const kFactory = Symbol('factory')
+const kQueued = Symbol('queued')
 
-class Pool extends EventEmitter {
-  constructor (origin, { connections, ...options } = {}) {
+function defaultFactory (origin, opts) {
+  return new Client(origin, opts)
+}
+
+class Pool extends Dispatcher {
+  constructor (origin, {
+    connections,
+    factory = defaultFactory,
+    connect,
+    connectTimeout,
+    tls,
+    maxCachedSessions,
+    socketPath,
+    ...options
+  } = {}) {
     super()
 
     if (connections != null && (!Number.isFinite(connections) || connections < 0)) {
       throw new InvalidArgumentError('invalid connections')
     }
 
+    if (typeof factory !== 'function') {
+      throw new InvalidArgumentError('factory must be a function.')
+    }
+
+    if (connect != null && typeof connect !== 'function' && typeof connect !== 'object') {
+      throw new InvalidArgumentError('connect must be a function or an object')
+    }
+
+    if (typeof connect !== 'function') {
+      connect = buildConnector({
+        ...tls,
+        maxCachedSessions,
+        socketPath,
+        timeout: connectTimeout == null ? 10e3 : connectTimeout,
+        ...connect
+      })
+    }
+
     this[kConnections] = connections || null
     this[kUrl] = util.parseOrigin(origin)
-    this[kOptions] = JSON.parse(JSON.stringify(options))
+    this[kOptions] = { ...util.deepClone(options), connect }
     this[kQueue] = new FixedQueue()
     this[kClosedPromise] = null
     this[kClosedResolve] = null
     this[kDestroyed] = false
     this[kClients] = []
     this[kNeedDrain] = false
-    this[kPending] = 0
-    this[kConnected] = 0
+    this[kQueued] = 0
+    this[kFactory] = factory
 
     const pool = this
 
-    this[kOnDrain] = function onDrain () {
+    this[kOnDrain] = function onDrain (url, targets) {
+      assert(pool[kUrl].origin === url.origin)
+
       const queue = pool[kQueue]
 
-      while (!this.busy) {
+      let needDrain = false
+
+      while (!needDrain) {
         const item = queue.shift()
         if (!item) {
           break
         }
-        pool[kPending]--
-        this.dispatch(item.opts, item.handler)
+        pool[kQueued]--
+        needDrain = !this.dispatch(item.opts, item.handler)
       }
 
-      if (pool[kNeedDrain] && !this.busy) {
+      this[kNeedDrain] = needDrain
+
+      if (!this[kNeedDrain] && pool[kNeedDrain]) {
         pool[kNeedDrain] = false
-        pool.emit('drain')
+        pool.emit('drain', origin, [pool, ...targets])
       }
 
       if (pool[kClosedResolve] && queue.isEmpty()) {
@@ -71,69 +111,44 @@ class Pool extends EventEmitter {
       }
     }
 
-    this[kOnConnect] = function onConnect () {
-      pool[kConnected]++
-      pool.emit('connect', this)
+    this[kOnConnect] = (origin, targets) => {
+      pool.emit('connect', origin, [pool, ...targets])
     }
 
-    this[kOnDisconnect] = function onDisconnect (err) {
-      pool[kConnected]--
-      pool.emit('disconnect', this, err)
+    this[kOnDisconnect] = (origin, targets, err) => {
+      pool.emit('disconnect', origin, [pool, ...targets], err)
+    }
+
+    this[kOnConnectionError] = (origin, targets, err) => {
+      pool.emit('connectionError', origin, [pool, ...targets], err)
     }
   }
 
-  get url () {
-    return this[kUrl]
+  get [kBusy] () {
+    return this[kNeedDrain]
   }
 
-  get connected () {
-    return this[kConnected]
-  }
-
-  get busy () {
-    if (this[kPending] > 0) {
-      return true
-    }
-
-    if (this[kConnections] && this[kClients].length === this[kConnections]) {
-      for (const { busy } of this[kClients]) {
-        if (!busy) {
-          return false
-        }
-      }
-      return true
-    }
-
-    return false
-  }
-
-  get pending () {
-    let ret = this[kPending]
-
-    for (const { pending } of this[kClients]) {
+  get [kPending] () {
+    let ret = this[kQueued]
+    for (const { [kPending]: pending } of this[kClients]) {
       ret += pending
     }
-
     return ret
   }
 
-  get running () {
+  get [kRunning] () {
     let ret = 0
-
-    for (const { running } of this[kClients]) {
+    for (const { [kRunning]: running } of this[kClients]) {
       ret += running
     }
-
     return ret
   }
 
-  get size () {
-    let ret = this[kPending]
-
-    for (const { size } of this[kClients]) {
+  get [kSize] () {
+    let ret = this[kQueued]
+    for (const { [kSize]: size } of this[kClients]) {
       ret += size
     }
-
     return ret
   }
 
@@ -146,6 +161,10 @@ class Pool extends EventEmitter {
   }
 
   dispatch (opts, handler) {
+    if (!handler || typeof handler !== 'object') {
+      throw new InvalidArgumentError('handler must be an object')
+    }
+
     try {
       if (this[kDestroyed]) {
         throw new ClientDestroyedError()
@@ -155,28 +174,26 @@ class Pool extends EventEmitter {
         throw new ClientClosedError()
       }
 
-      let client = this[kClients].find(client => !client.busy)
+      let dispatcher = this[kClients].find(dispatcher => !dispatcher[kNeedDrain])
 
-      if (!client) {
+      if (!dispatcher) {
         if (!this[kConnections] || this[kClients].length < this[kConnections]) {
-          client = new Client(this[kUrl], this[kOptions])
+          dispatcher = this[kFactory](this[kUrl], this[kOptions])
             .on('drain', this[kOnDrain])
             .on('connect', this[kOnConnect])
             .on('disconnect', this[kOnDisconnect])
-
-          this[kClients].push(client)
+            .on('connectionError', this[kOnConnectionError])
+          this[kClients].push(dispatcher)
         }
       }
 
-      if (!client) {
+      if (!dispatcher) {
         this[kNeedDrain] = true
         this[kQueue].push({ opts, handler })
-        this[kPending]++
-      } else {
-        client.dispatch(opts, handler)
-        if (client.busy && this.busy) {
-          this[kNeedDrain] = true
-        }
+        this[kQueued]++
+      } else if (!dispatcher.dispatch(opts, handler)) {
+        dispatcher[kNeedDrain] = true
+        this[kNeedDrain] = this[kConnections] && this[kClients].length === this[kConnections]
       }
     } catch (err) {
       if (typeof handler.onError !== 'function') {
@@ -185,6 +202,8 @@ class Pool extends EventEmitter {
 
       handler.onError(err)
     }
+
+    return !this[kNeedDrain]
   }
 
   close (cb) {
@@ -249,10 +268,4 @@ class Pool extends EventEmitter {
   }
 }
 
-Pool.prototype.request = require('./client-request')
-Pool.prototype.stream = require('./client-stream')
-Pool.prototype.pipeline = require('./client-pipeline')
-Pool.prototype.upgrade = require('./client-upgrade')
-Pool.prototype.connect = require('./client-connect')
-
 module.exports = Pool
