@@ -63,6 +63,7 @@ function Reply (res, request, log) {
   this[kReplyStartTime] = undefined
   this.log = log
 }
+Reply.props = []
 
 Object.defineProperties(Reply.prototype, {
   context: {
@@ -377,8 +378,8 @@ function preserializeHookEnd (err, request, reply, payload) {
 }
 
 function onSendHook (reply, payload) {
-  reply[kReplySent] = true
   if (reply.context.onSend !== null) {
+    reply[kReplySent] = true
     onSendHookRunner(
       reply.context.onSend,
       reply.request,
@@ -422,6 +423,8 @@ function onSendEnd (reply, payload) {
   }
 
   if (typeof payload.pipe === 'function') {
+    reply[kReplySent] = true
+
     sendStream(payload, res, reply)
     return
   }
@@ -548,8 +551,12 @@ function handleError (reply, error, cb) {
     reply[kReplyErrorHandlerCalled] = true
     reply[kReplyHeaders]['content-length'] = undefined
     const result = errorHandler(error, reply.request, reply)
-    if (result && typeof result.then === 'function') {
-      wrapThenable(result, reply)
+    if (result !== undefined) {
+      if (result !== null && typeof result.then === 'function') {
+        wrapThenable(result, reply)
+      } else {
+        reply.send(result)
+      }
     }
     return
   }
@@ -569,12 +576,17 @@ function handleError (reply, error, cb) {
         message: { value: error.message || '' },
         statusCode: { value: statusCode }
       }))
+
+    if (serializerFn !== false && typeof payload !== 'string') {
+      throw new FST_ERR_REP_INVALID_PAYLOAD_TYPE(typeof payload)
+    }
   } catch (err) {
     // error is always FST_ERR_SCH_SERIALIZATION_BUILD because this is called from route/compileSchemasForSerialization
     reply.log.error({ err, statusCode: res.statusCode }, 'The serializer for the given status code failed')
     res.statusCode = 500
     payload = serializeError({
       error: statusCodes['500'],
+      code: err.code,
       message: err.message,
       statusCode: 500
     })
@@ -647,6 +659,8 @@ function onResponseCallback (err, request, reply) {
 }
 
 function buildReply (R) {
+  const props = [...R.props]
+
   function _Reply (res, request, log) {
     this.raw = res
     this[kReplyIsError] = false
@@ -658,8 +672,14 @@ function buildReply (R) {
     this[kReplyHeaders] = {}
     this[kReplyStartTime] = undefined
     this.log = log
+
+    // eslint-disable-next-line no-var
+    for (var i = 0; i < props.length; i++) {
+      this[props[i]] = null
+    }
   }
   _Reply.prototype = new R()
+  _Reply.props = props
   return _Reply
 }
 
