@@ -6,11 +6,16 @@
 'use strict';
 
 const docsUrl = require('../util/docsUrl');
+const report = require('../util/report');
 
 // ------------------------------------------------------------------------------
 // Rule Definition
 // ------------------------------------------------------------------------------
 
+const messages = {
+  noFindDOMNode: 'Do not use findDOMNode. It doesn’t work with function components and is deprecated in StrictMode. See https://reactjs.org/docs/react-dom.html#finddomnode'
+};
+
 module.exports = {
   meta: {
     docs: {
@@ -20,20 +25,13 @@ module.exports = {
       url: docsUrl('no-find-dom-node')
     },
 
-    messages: {
-      noFindDOMNode: 'Do not use findDOMNode. It doesn’t work with function components and is deprecated in StrictMode. See https://reactjs.org/docs/react-dom.html#finddomnode'
-    },
+    messages,
 
     schema: []
   },
 
   create(context) {
-    // --------------------------------------------------------------------------
-    // Public
-    // --------------------------------------------------------------------------
-
     return {
-
       CallExpression(node) {
         const callee = node.callee;
 
@@ -43,9 +41,8 @@ module.exports = {
           return;
         }
 
-        context.report({
-          node: callee,
-          messageId: 'noFindDOMNode'
+        report(context, messages.noFindDOMNode, 'noFindDOMNode', {
+          node: callee
         });
       }
     };
