@@ -12,41 +12,35 @@
 
 var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
 
+var _createForOfIteratorHelper2 = _interopRequireDefault(require("@babel/runtime/helpers/createForOfIteratorHelper"));
+
 var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
 
-function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }
-
-function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
-
-function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
-
 var DataChecker = require('./DataChecker');
 
+var RelayFeatureFlags = require('../util/RelayFeatureFlags');
+
 var RelayModernRecord = require('./RelayModernRecord');
 
 var RelayOptimisticRecordSource = require('./RelayOptimisticRecordSource');
 
-var RelayProfiler = require('../util/RelayProfiler');
-
 var RelayReader = require('./RelayReader');
 
 var RelayReferenceMarker = require('./RelayReferenceMarker');
 
 var RelayStoreReactFlightUtils = require('./RelayStoreReactFlightUtils');
 
+var RelayStoreSubscriptions = require('./RelayStoreSubscriptions');
+
+var RelayStoreSubscriptionsUsingMapByID = require('./RelayStoreSubscriptionsUsingMapByID');
+
 var RelayStoreUtils = require('./RelayStoreUtils');
 
 var deepFreeze = require('../util/deepFreeze');
 
 var defaultGetDataID = require('./defaultGetDataID');
 
-var hasOverlappingIDs = require('./hasOverlappingIDs');
-
-var invariant = require("fbjs/lib/invariant");
-
-var isEmptyObject = require('../util/isEmptyObject');
-
-var recycleNodesInto = require('../util/recycleNodesInto');
+var invariant = require('invariant');
 
 var resolveImmediate = require('../util/resolveImmediate');
 
@@ -54,7 +48,7 @@ var _require = require('./RelayStoreUtils'),
     ROOT_ID = _require.ROOT_ID,
     ROOT_TYPE = _require.ROOT_TYPE;
 
-var DEFAULT_RELEASE_BUFFER_SIZE = 0;
+var DEFAULT_RELEASE_BUFFER_SIZE = 10;
 /**
  * @public
  *
@@ -72,7 +66,7 @@ var RelayModernStore = /*#__PURE__*/function () {
   function RelayModernStore(source, options) {
     var _this = this;
 
-    var _options$gcReleaseBuf, _options$gcScheduler, _options$UNSTABLE_DO_, _options$log, _options$operationLoa;
+    var _options$gcReleaseBuf, _options$gcScheduler, _options$getDataID, _options$log, _options$operationLoa;
 
     (0, _defineProperty2["default"])(this, "_gcStep", function () {
       if (_this._gcRun) {
@@ -102,7 +96,7 @@ var RelayModernStore = /*#__PURE__*/function () {
     this._gcReleaseBufferSize = (_options$gcReleaseBuf = options === null || options === void 0 ? void 0 : options.gcReleaseBufferSize) !== null && _options$gcReleaseBuf !== void 0 ? _options$gcReleaseBuf : DEFAULT_RELEASE_BUFFER_SIZE;
     this._gcRun = null;
     this._gcScheduler = (_options$gcScheduler = options === null || options === void 0 ? void 0 : options.gcScheduler) !== null && _options$gcScheduler !== void 0 ? _options$gcScheduler : resolveImmediate;
-    this._getDataID = (_options$UNSTABLE_DO_ = options === null || options === void 0 ? void 0 : options.UNSTABLE_DO_NOT_USE_getDataID) !== null && _options$UNSTABLE_DO_ !== void 0 ? _options$UNSTABLE_DO_ : defaultGetDataID;
+    this._getDataID = (_options$getDataID = options === null || options === void 0 ? void 0 : options.getDataID) !== null && _options$getDataID !== void 0 ? _options$getDataID : defaultGetDataID;
     this._globalInvalidationEpoch = null;
     this._invalidationSubscriptions = new Set();
     this._invalidatedRecordIDs = new Set();
@@ -114,8 +108,9 @@ var RelayModernStore = /*#__PURE__*/function () {
     this._releaseBuffer = [];
     this._roots = new Map();
     this._shouldScheduleGC = false;
-    this._subscriptions = new Set();
-    this._updatedRecordIDs = {};
+    this._storeSubscriptions = RelayFeatureFlags.ENABLE_STORE_SUBSCRIPTIONS_REFACTOR === true ? new RelayStoreSubscriptionsUsingMapByID(options === null || options === void 0 ? void 0 : options.log) : new RelayStoreSubscriptions(options === null || options === void 0 ? void 0 : options.log);
+    this._updatedRecordIDs = new Set();
+    this._shouldProcessClientComponents = options === null || options === void 0 ? void 0 : options.shouldProcessClientComponents;
     initializeRecordSource(this._recordSource);
   }
 
@@ -154,7 +149,7 @@ var RelayModernStore = /*#__PURE__*/function () {
 
     var target = (_options$target = options === null || options === void 0 ? void 0 : options.target) !== null && _options$target !== void 0 ? _options$target : source;
     var handlers = (_options$handlers = options === null || options === void 0 ? void 0 : options.handlers) !== null && _options$handlers !== void 0 ? _options$handlers : [];
-    var operationAvailability = DataChecker.check(source, target, selector, handlers, this._operationLoader, this._getDataID);
+    var operationAvailability = DataChecker.check(source, target, selector, handlers, this._operationLoader, this._getDataID, this._shouldProcessClientComponents);
     return getAvailabilityStatus(operationAvailability, operationLastWrittenAt, rootEntry === null || rootEntry === void 0 ? void 0 : rootEntry.fetchTime, this._queryCacheExpirationTime);
   };
 
@@ -256,7 +251,8 @@ var RelayModernStore = /*#__PURE__*/function () {
 
     if (log != null) {
       log({
-        name: 'store.notify.start'
+        name: 'store.notify.start',
+        sourceOperation: sourceOperation
       });
     } // Increment the current write when notifying after executing
     // a set of changes to the store.
@@ -270,15 +266,8 @@ var RelayModernStore = /*#__PURE__*/function () {
 
     var source = this.getSource();
     var updatedOwners = [];
-    var hasUpdatedRecords = !isEmptyObject(this._updatedRecordIDs);
 
-    this._subscriptions.forEach(function (subscription) {
-      var owner = _this3._updateSubscription(source, subscription, hasUpdatedRecords);
-
-      if (owner != null) {
-        updatedOwners.push(owner);
-      }
-    });
+    this._storeSubscriptions.updateSubscriptions(source, this._updatedRecordIDs, updatedOwners, sourceOperation);
 
     this._invalidationSubscriptions.forEach(function (subscription) {
       _this3._updateInvalidationSubscription(subscription, invalidateStore === true);
@@ -287,12 +276,13 @@ var RelayModernStore = /*#__PURE__*/function () {
     if (log != null) {
       log({
         name: 'store.notify.complete',
+        sourceOperation: sourceOperation,
         updatedRecordIDs: this._updatedRecordIDs,
         invalidatedRecordIDs: this._invalidatedRecordIDs
       });
     }
 
-    this._updatedRecordIDs = {};
+    this._updatedRecordIDs.clear();
 
     this._invalidatedRecordIDs.clear(); // If a source operation was provided (indicating the operation
     // that produced this update to the store), record the current epoch
@@ -353,28 +343,11 @@ var RelayModernStore = /*#__PURE__*/function () {
   };
 
   _proto.subscribe = function subscribe(snapshot, callback) {
-    var _this4 = this;
-
-    var subscription = {
-      backup: null,
-      callback: callback,
-      snapshot: snapshot,
-      stale: false
-    };
-
-    var dispose = function dispose() {
-      _this4._subscriptions["delete"](subscription);
-    };
-
-    this._subscriptions.add(subscription);
-
-    return {
-      dispose: dispose
-    };
+    return this._storeSubscriptions.subscribe(snapshot, callback);
   };
 
   _proto.holdGC = function holdGC() {
-    var _this5 = this;
+    var _this4 = this;
 
     if (this._gcRun) {
       this._gcRun = null;
@@ -384,13 +357,13 @@ var RelayModernStore = /*#__PURE__*/function () {
     this._gcHoldCounter++;
 
     var dispose = function dispose() {
-      if (_this5._gcHoldCounter > 0) {
-        _this5._gcHoldCounter--;
+      if (_this4._gcHoldCounter > 0) {
+        _this4._gcHoldCounter--;
 
-        if (_this5._gcHoldCounter === 0 && _this5._shouldScheduleGC) {
-          _this5.scheduleGC();
+        if (_this4._gcHoldCounter === 0 && _this4._shouldScheduleGC) {
+          _this4.scheduleGC();
 
-          _this5._shouldScheduleGC = false;
+          _this4._shouldScheduleGC = false;
         }
       }
     };
@@ -407,52 +380,16 @@ var RelayModernStore = /*#__PURE__*/function () {
 
   _proto.__getUpdatedRecordIDs = function __getUpdatedRecordIDs() {
     return this._updatedRecordIDs;
-  } // Returns the owner (RequestDescriptor) if the subscription was affected by the
-  // latest update, or null if it was not affected.
-  ;
-
-  _proto._updateSubscription = function _updateSubscription(source, subscription, hasUpdatedRecords) {
-    var backup = subscription.backup,
-        callback = subscription.callback,
-        snapshot = subscription.snapshot,
-        stale = subscription.stale;
-    var hasOverlappingUpdates = hasUpdatedRecords && hasOverlappingIDs(snapshot.seenRecords, this._updatedRecordIDs);
-
-    if (!stale && !hasOverlappingUpdates) {
-      return;
-    }
-
-    var nextSnapshot = hasOverlappingUpdates || !backup ? RelayReader.read(source, snapshot.selector) : backup;
-    var nextData = recycleNodesInto(snapshot.data, nextSnapshot.data);
-    nextSnapshot = {
-      data: nextData,
-      isMissingData: nextSnapshot.isMissingData,
-      seenRecords: nextSnapshot.seenRecords,
-      selector: nextSnapshot.selector,
-      missingRequiredFields: nextSnapshot.missingRequiredFields
-    };
-
-    if (process.env.NODE_ENV !== "production") {
-      deepFreeze(nextSnapshot);
-    }
-
-    subscription.snapshot = nextSnapshot;
-    subscription.stale = false;
-
-    if (nextSnapshot.data !== snapshot.data) {
-      callback(nextSnapshot);
-      return snapshot.selector.owner;
-    }
   };
 
   _proto.lookupInvalidationState = function lookupInvalidationState(dataIDs) {
-    var _this6 = this;
+    var _this5 = this;
 
     var invalidations = new Map();
     dataIDs.forEach(function (dataID) {
       var _RelayModernRecord$ge;
 
-      var record = _this6.getSource().get(dataID);
+      var record = _this5.getSource().get(dataID);
 
       invalidations.set(dataID, (_RelayModernRecord$ge = RelayModernRecord.getInvalidationEpoch(record)) !== null && _RelayModernRecord$ge !== void 0 ? _RelayModernRecord$ge : null);
     });
@@ -473,7 +410,7 @@ var RelayModernStore = /*#__PURE__*/function () {
     } // Check if the invalidation state for any of the ids has changed.
 
 
-    var _iterator = _createForOfIteratorHelper(prevInvalidationState.dataIDs),
+    var _iterator = (0, _createForOfIteratorHelper2["default"])(prevInvalidationState.dataIDs),
         _step;
 
     try {
@@ -494,7 +431,7 @@ var RelayModernStore = /*#__PURE__*/function () {
   };
 
   _proto.subscribeToInvalidationState = function subscribeToInvalidationState(invalidationState, callback) {
-    var _this7 = this;
+    var _this6 = this;
 
     var subscription = {
       callback: callback,
@@ -502,7 +439,7 @@ var RelayModernStore = /*#__PURE__*/function () {
     };
 
     var dispose = function dispose() {
-      _this7._invalidationSubscriptions["delete"](subscription);
+      _this6._invalidationSubscriptions["delete"](subscription);
     };
 
     this._invalidationSubscriptions.add(subscription);
@@ -513,13 +450,13 @@ var RelayModernStore = /*#__PURE__*/function () {
   };
 
   _proto._updateInvalidationSubscription = function _updateInvalidationSubscription(subscription, invalidatedStore) {
-    var _this8 = this;
+    var _this7 = this;
 
     var callback = subscription.callback,
         invalidationState = subscription.invalidationState;
     var dataIDs = invalidationState.dataIDs;
     var isSubscribedToInvalidatedIDs = invalidatedStore || dataIDs.some(function (dataID) {
-      return _this8._invalidatedRecordIDs.has(dataID);
+      return _this7._invalidatedRecordIDs.has(dataID);
     });
 
     if (!isSubscribedToInvalidatedIDs) {
@@ -530,8 +467,6 @@ var RelayModernStore = /*#__PURE__*/function () {
   };
 
   _proto.snapshot = function snapshot() {
-    var _this9 = this;
-
     !(this._optimisticSource == null) ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayModernStore: Unexpected call to snapshot() while a previous ' + 'snapshot exists.') : invariant(false) : void 0;
     var log = this.__log;
 
@@ -541,31 +476,7 @@ var RelayModernStore = /*#__PURE__*/function () {
       });
     }
 
-    this._subscriptions.forEach(function (subscription) {
-      // Backup occurs after writing a new "final" payload(s) and before (re)applying
-      // optimistic changes. Each subscription's `snapshot` represents what was *last
-      // published to the subscriber*, which notably may include previous optimistic
-      // updates. Therefore a subscription can be in any of the following states:
-      // - stale=true: This subscription was restored to a different value than
-      //   `snapshot`. That means this subscription has changes relative to its base,
-      //   but its base has changed (we just applied a final payload): recompute
-      //   a backup so that we can later restore to the state the subscription
-      //   should be in.
-      // - stale=false: This subscription was restored to the same value than
-      //   `snapshot`. That means this subscription does *not* have changes relative
-      //   to its base, so the current `snapshot` is valid to use as a backup.
-      if (!subscription.stale) {
-        subscription.backup = subscription.snapshot;
-        return;
-      }
-
-      var snapshot = subscription.snapshot;
-      var backup = RelayReader.read(_this9.getSource(), snapshot.selector);
-      var nextData = recycleNodesInto(snapshot.data, backup.data);
-      backup.data = nextData; // backup owns the snapshot and can safely mutate
-
-      subscription.backup = backup;
-    });
+    this._storeSubscriptions.snapshotSubscriptions(this.getSource());
 
     if (this._gcRun) {
       this._gcRun = null;
@@ -591,26 +502,7 @@ var RelayModernStore = /*#__PURE__*/function () {
       this.scheduleGC();
     }
 
-    this._subscriptions.forEach(function (subscription) {
-      var backup = subscription.backup;
-      subscription.backup = null;
-
-      if (backup) {
-        if (backup.data !== subscription.snapshot.data) {
-          subscription.stale = true;
-        }
-
-        subscription.snapshot = {
-          data: subscription.snapshot.data,
-          isMissingData: backup.isMissingData,
-          seenRecords: backup.seenRecords,
-          selector: backup.selector,
-          missingRequiredFields: backup.missingRequiredFields
-        };
-      } else {
-        subscription.stale = true;
-      }
-    });
+    this._storeSubscriptions.restoreSubscriptions();
   };
 
   _proto.scheduleGC = function scheduleGC() {
@@ -649,14 +541,14 @@ var RelayModernStore = /*#__PURE__*/function () {
       var startEpoch = this._currentWriteEpoch;
       var references = new Set(); // Mark all records that are traversable from a root
 
-      var _iterator2 = _createForOfIteratorHelper(this._roots.values()),
+      var _iterator2 = (0, _createForOfIteratorHelper2["default"])(this._roots.values()),
           _step2;
 
       try {
         for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
           var operation = _step2.value.operation;
           var selector = operation.root;
-          RelayReferenceMarker.mark(this._recordSource, selector, references, this._operationLoader); // Yield for other work after each operation
+          RelayReferenceMarker.mark(this._recordSource, selector, references, this._operationLoader, this._shouldProcessClientComponents); // Yield for other work after each operation
 
           yield; // If the store was updated, restart
 
@@ -754,7 +646,8 @@ function updateTargetFromSource(target, source, currentWriteEpoch, idsMarkedForI
       }
 
       RelayModernRecord.setValue(nextRecord, RelayStoreUtils.INVALIDATED_AT_KEY, currentWriteEpoch);
-      invalidatedRecordIDs.add(dataID);
+      invalidatedRecordIDs.add(dataID); // $FlowFixMe[incompatible-call]
+
       target.set(dataID, nextRecord);
     });
   } // Update the target based on the changes present in source
@@ -786,18 +679,18 @@ function updateTargetFromSource(target, source, currentWriteEpoch, idsMarkedForI
           RelayModernRecord.freeze(nextRecord);
         }
 
-        updatedRecordIDs[dataID] = true;
+        updatedRecordIDs.add(dataID);
         target.set(dataID, nextRecord);
       }
     } else if (sourceRecord === null) {
       target["delete"](dataID);
 
       if (targetRecord !== null) {
-        updatedRecordIDs[dataID] = true;
+        updatedRecordIDs.add(dataID);
       }
     } else if (sourceRecord) {
       target.set(dataID, sourceRecord);
-      updatedRecordIDs[dataID] = true;
+      updatedRecordIDs.add(dataID);
     } // don't add explicit undefined
 
   }
@@ -852,7 +745,4 @@ function getAvailabilityStatus(operationAvailability, operationLastWrittenAt, op
   };
 }
 
-RelayProfiler.instrumentMethods(RelayModernStore.prototype, {
-  lookup: 'RelayModernStore.prototype.lookup'
-});
 module.exports = RelayModernStore;
\ No newline at end of file
