@@ -12,14 +12,10 @@
 
 var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
 
-var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
+var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
 
 var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
 
-function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }
-
-function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
-
 var IRTransformer = require('../core/IRTransformer');
 
 var RelayParser = require('../core/RelayParser');
@@ -82,8 +78,8 @@ function visitFragmentOrRoot(node, options) {
   var connectionMetadata = options.connectionMetadata;
 
   if (connectionMetadata.length) {
-    return _objectSpread(_objectSpread({}, transformedNode), {}, {
-      metadata: _objectSpread(_objectSpread({}, transformedNode.metadata), {}, {
+    return (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedNode), {}, {
+      metadata: (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedNode.metadata), {}, {
         connection: connectionMetadata
       })
     });
@@ -104,7 +100,7 @@ function visitLinkedField(field, options) {
   var nullableType = schema.getNullableType(field.type);
   var isPlural = schema.isList(nullableType);
   var path = options.path.concat(isPlural ? null : field.alias || field.name);
-  var transformedField = this.traverse(field, _objectSpread(_objectSpread({}, options), {}, {
+  var transformedField = this.traverse(field, (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, options), {}, {
     path: path
   }));
   var connectionDirective = field.directives.find(function (directive) {
@@ -134,12 +130,12 @@ function visitLinkedField(field, options) {
 
   if (direction != null) {
     var selections = transformConnectionSelections(this.getContext(), transformedField, schema.assertCompositeType(nullableType), direction, connectionArguments, connectionDirective.loc, options.documentName);
-    transformedField = _objectSpread(_objectSpread({}, transformedField), {}, {
+    transformedField = (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedField), {}, {
       selections: selections
     });
   }
 
-  return _objectSpread(_objectSpread({}, transformedField), {}, {
+  return (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedField), {}, {
     directives: transformedField.directives.filter(function (directive) {
       return directive !== connectionDirective;
     }),
@@ -451,7 +447,7 @@ function transformConnectionSelections(context, field, nullableType, direction,
     throw createCompilerError('ConnectionTransform: Expected generated pageInfo selection to be ' + 'a LinkedField', [field.loc]);
   }
 
-  transformedPageInfoSelection = _objectSpread(_objectSpread({}, transformedPageInfoSelection), {}, {
+  transformedPageInfoSelection = (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedPageInfoSelection), {}, {
     selections: [].concat((0, _toConsumableArray2["default"])(transformedPageInfoSelection.selections), [{
       directives: [],
       kind: 'InlineFragment',
@@ -480,7 +476,7 @@ function transformConnectionSelections(context, field, nullableType, direction,
   var edgeAst = parse(edgeText);
   var edgeFragment = RelayParser.transform(schema, [edgeAst.definitions[0]])[0]; // When streaming the edges field needs @stream
 
-  transformedEdgesSelection = _objectSpread(_objectSpread({}, transformedEdgesSelection), {}, {
+  transformedEdgesSelection = (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, transformedEdgesSelection), {}, {
     directives: streamDirective != null ? [].concat((0, _toConsumableArray2["default"])(transformedEdgesSelection.directives), [streamDirective]) : transformedEdgesSelection.directives,
     selections: [].concat((0, _toConsumableArray2["default"])(transformedEdgesSelection.selections), [{
       directives: [],
