@@ -12,12 +12,19 @@
 
 var RelayFeatureFlags = {
   ENABLE_VARIABLE_CONNECTION_KEY: false,
-  ENABLE_PARTIAL_RENDERING_DEFAULT: false,
-  ENABLE_RELAY_CONTAINERS_SUSPENSE: false,
+  ENABLE_PARTIAL_RENDERING_DEFAULT: true,
+  ENABLE_RELAY_CONTAINERS_SUSPENSE: true,
   ENABLE_PRECISE_TYPE_REFINEMENT: false,
   ENABLE_REACT_FLIGHT_COMPONENT_FIELD: false,
   ENABLE_REQUIRED_DIRECTIVES: false,
+  ENABLE_RELAY_RESOLVERS: false,
   ENABLE_GETFRAGMENTIDENTIFIER_OPTIMIZATION: false,
-  ENABLE_FRIENDLY_QUERY_NAME_GQL_URL: false
+  ENABLE_FRIENDLY_QUERY_NAME_GQL_URL: false,
+  ENABLE_STORE_SUBSCRIPTIONS_REFACTOR: false,
+  ENABLE_LOAD_QUERY_REQUEST_DEDUPING: true,
+  ENABLE_DO_NOT_WRAP_LIVE_QUERY: false,
+  ENABLE_NOTIFY_SUBSCRIPTION: false,
+  ENABLE_UNIQUE_SUBSCRIPTION_ROOT: false,
+  ENABLE_BATCHED_STORE_UPDATES: false
 };
 module.exports = RelayFeatureFlags;
\ No newline at end of file
