@@ -18,7 +18,7 @@ const instance = Fastify({
 instance.register(From)
 
 t.plan(9)
-t.tearDown(instance.close.bind(instance))
+t.teardown(instance.close.bind(instance))
 
 const target = https.createServer(certs, (req, res) => {
   t.pass('request proxied')
@@ -33,7 +33,7 @@ instance.get('/', (request, reply) => {
   reply.from(`https://localhost:${target.address().port}`)
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 instance.listen(0, (err) => {
   t.error(err)
