@@ -13,12 +13,12 @@ t.test('issue-145', (t) => {
   findMyWay.on('GET', '/a/b', fixedPath)
   findMyWay.on('GET', '/a/:pam/c', varPath)
 
-  t.equals(findMyWay.find('GET', '/a/b').handler, fixedPath)
-  t.equals(findMyWay.find('GET', '/a/b/').handler, fixedPath)
-  t.equals(findMyWay.find('GET', '/a/b/c').handler, varPath)
-  t.equals(findMyWay.find('GET', '/a/b/c/').handler, varPath)
-  t.equals(findMyWay.find('GET', '/a/foo/c').handler, varPath)
-  t.equals(findMyWay.find('GET', '/a/foo/c/').handler, varPath)
+  t.equal(findMyWay.find('GET', '/a/b').handler, fixedPath)
+  t.equal(findMyWay.find('GET', '/a/b/').handler, fixedPath)
+  t.equal(findMyWay.find('GET', '/a/b/c').handler, varPath)
+  t.equal(findMyWay.find('GET', '/a/b/c/').handler, varPath)
+  t.equal(findMyWay.find('GET', '/a/foo/c').handler, varPath)
+  t.equal(findMyWay.find('GET', '/a/foo/c/').handler, varPath)
   t.notOk(findMyWay.find('GET', '/a/c'))
   t.notOk(findMyWay.find('GET', '/a/c/'))
 })
