@@ -13,15 +13,15 @@ test('proxy socket.io', async t => {
   t.plan(2)
 
   const srvUpstream = createServer()
-  t.tearDown(srvUpstream.close.bind(srvUpstream))
+  t.teardown(srvUpstream.close.bind(srvUpstream))
 
   const srvSocket = new ioServer.Server(srvUpstream)
-  t.tearDown(srvSocket.close.bind(srvSocket))
+  t.teardown(srvSocket.close.bind(srvSocket))
 
   await promisify(srvUpstream.listen.bind(srvUpstream))(0)
 
   const srvProxy = Fastify()
-  t.tearDown(srvProxy.close.bind(srvProxy))
+  t.teardown(srvProxy.close.bind(srvProxy))
 
   srvProxy.register(proxy, {
     upstream: `http://127.0.0.1:${srvUpstream.address().port}`,
@@ -32,18 +32,18 @@ test('proxy socket.io', async t => {
 
   srvSocket.on('connection', socket => {
     socket.on('hello', data => {
-      t.is(data, 'world')
+      t.equal(data, 'world')
       socket.emit('hi', 'socket')
     })
   })
 
   const cliSocket = ioClient(`http://127.0.0.1:${srvProxy.server.address().port}`)
-  t.tearDown(cliSocket.close.bind(cliSocket))
+  t.teardown(cliSocket.close.bind(cliSocket))
 
   cliSocket.emit('hello', 'world')
 
   const out = await once(cliSocket, 'hi')
-  t.is(out[0], 'socket')
+  t.equal(out[0], 'socket')
 
   await Promise.all([
     once(cliSocket, 'disconnect'),
